@@ -28,15 +28,11 @@ program index
   logical              :: index_exists
   character(len=10)    :: index_file='index.idx'
 
-  inquire( file=index_file, exist=index_exists )
+  ! uncomment following line to load index from file
+  !call grib_index_read(idx,index_file)
 
-  if (index_exists) then
-    ! load index from file
-    call grib_index_read(idx,index_file)
-  else
-    ! create an index from a grib file using some keys
-    call grib_index_create(idx,'../../data/index.grib','shortName,number,level,step')
-  endif
+  ! create an index from a grib file using some keys
+  call grib_index_create(idx,'../../data/index.grib','shortName,number,level,step')
 
   ! get the number of distinct values of shortName in the index
   call grib_index_get_size(idx,'shortName',shortNameSize)
