@@ -56,8 +56,9 @@ extern int errno;
 typedef struct l_grib_file l_grib_file;
 
 struct l_grib_file {
-  int id;
   FILE* f;
+  char* buffer;
+  int id;
   l_grib_file* next;
 };
 
@@ -140,7 +141,7 @@ static void fort_char_clean(char* str,int len) {
 }
 
 
-static int push_file(FILE* f){
+static int push_file(FILE* f,char* buffer){
   l_grib_file* current  = file_set;
   l_grib_file* previous = file_set;
   l_grib_file* new      = NULL;
@@ -150,6 +151,7 @@ static int push_file(FILE* f){
     file_set = malloc(sizeof(l_grib_file));
     file_set->id   = myindex;
     file_set->f    = f;
+	file_set->buffer =buffer;
     file_set->next = NULL;
     return myindex;
   }
@@ -158,6 +160,7 @@ static int push_file(FILE* f){
     if(current->id < 0){
       current->id = -(current->id);
       current->f    = f;
+      current->buffer    = buffer;
       return current->id ;
     } else{
       myindex++;
@@ -166,9 +169,10 @@ static int push_file(FILE* f){
     }
   }
 
-  new = malloc(sizeof(l_grib_handle));
+  new = malloc(sizeof(l_grib_file));
   new->id   = myindex;
   new->f    = f;
+  new->buffer    = buffer;
   new->next = current;
   previous->next = new;
   return myindex;
@@ -561,6 +565,7 @@ static int clear_file(int file_id){
     if(current->id == file_id){
       current->id = -(current->id);
       if (current->f) fclose(current->f);
+      if (current->buffer) free(current->buffer);
       return GRIB_SUCCESS;
     }
     current = current->next;
@@ -683,6 +688,28 @@ static int clear_keys_iterator(int keys_iterator_id){
   return ret;
 }
 
+int grib_f_read_any_headers_only_from_file_(int* fid, char* buffer, int* nbytes) {
+  grib_context* c;
+  int err=0;
+  size_t size=(size_t)*nbytes;
+  FILE* f=get_file(*fid);
+
+  if (f) {
+    c=grib_context_get_default( );
+    err=grib_read_any_headers_only_from_file(c,f,buffer,&size);
+	*nbytes=size;
+	return err;
+  } else {
+    return GRIB_INVALID_FILE;
+  }
+}
+int grib_f_read_any_headers_only_from_file__(int* fid, char* buffer, int* nbytes) {
+	return grib_f_read_any_headers_only_from_file_(fid,buffer,nbytes);
+}
+int grib_f_read_any_headers_only_from_file(int* fid, char* buffer, int* nbytes) {
+	return grib_f_read_any_headers_only_from_file_(fid,buffer,nbytes);
+}
+
 int grib_f_read_any_from_file_(int* fid, char* buffer, int* nbytes) {
   grib_context* c;
   int err=0;
@@ -761,6 +788,7 @@ int grib_f_open_file_(int* fid, char* name , char* op, int lname, int lop){
   char *p;
   char fname[1024];
   int ret=GRIB_SUCCESS;
+  char* iobuf=NULL;
   /*TODO Proper context passed as external parameter */
   grib_context* context=grib_context_get_default();
 
@@ -771,15 +799,28 @@ int grib_f_open_file_(int* fid, char* name , char* op, int lname, int lop){
   while (*p != '\0') { *p=tolower(*p);p++;}
 
   f = fopen(cast_char(fname,name,lname),oper);
-
   if(!f) {
     ioerr=errno;
     grib_context_log(context,(GRIB_LOG_ERROR)|(GRIB_LOG_PERROR),"IO ERROR: %s: %s",strerror(ioerr),cast_char(fname,name,lname));
     *fid = -1;
      ret=GRIB_IO_PROBLEM;
   } else {
-    *fid = push_file(f);
-    ret=GRIB_SUCCESS;
+	if (context->io_buffer_size) {
+		/* printf("setting vbuf = %d\n",context->io_buffer_size); */
+#ifdef POSIX_MEMALIGN
+		if (posix_memalign((void **)&iobuf,sysconf(_SC_PAGESIZE),context->io_buffer_size) ) {
+		         grib_context_log(context,GRIB_LOG_FATAL,"grib_f_open_file_: posix_memalign unable to allocate io_buffer\n");
+		}
+#else
+    iobuf = (void*)malloc(context->io_buffer_size);
+    if (!iobuf) {
+      grib_context_log(context,GRIB_LOG_FATAL,"grib_f_open_file_: Unable to allocate io_buffer\n");
+    }
+#endif
+		setvbuf(f,iobuf,_IOFBF,context->io_buffer_size);
+	}
+	*fid = push_file(f,iobuf);
+	ret=GRIB_SUCCESS;
   }
   return ret;
 }
@@ -801,6 +842,25 @@ int grib_f_close_file(int* fid){
   return grib_f_close_file_(fid);
 }
 
+void grib_f_write_on_fail(int* gid) {
+	grib_context* c=grib_context_get_default();
+	if (c->write_on_fail) {
+		char filename[100]={0,};
+		grib_handle* h=NULL;
+		clock_t t;
+		t=times(NULL);
+		t=t<0?-t:t;
+		sprintf(filename,"%ld_error.grib",(long)t);
+		h=get_handle(*gid);
+		if (h) grib_write_message(h,filename,"w");
+	}
+}
+void grib_f_write_on_fail_(int* gid) {
+	grib_f_write_on_fail(gid);
+}
+void grib_f_write_on_fail__(int* gid) {
+	grib_f_write_on_fail(gid);
+}
 int grib_f_multi_support_on_(){
   grib_multi_support_on(0);
   return GRIB_SUCCESS;
@@ -1185,6 +1245,27 @@ int grib_f_clone(int* gidsrc,int* giddest){
   return grib_f_clone_(gidsrc, giddest);
 }
 
+int grib_f_util_sections_copy_(int* gidfrom,int* gidto,int* what,int *gidout){
+	int err=0;
+	grib_handle *hfrom  = get_handle(*gidfrom);
+	grib_handle *hto = get_handle(*gidto);
+	grib_handle *out =0; 
+
+	if(hfrom && hto) out=grib_util_sections_copy(hfrom,hto,*what,&err);
+	if(out){
+	      push_handle(out,gidout);
+	      return GRIB_SUCCESS;
+	}		   
+	
+	return err;
+}
+int grib_f_util_sections_copy__(int* gidfrom,int* gidto,int* what,int *gidout){
+	return grib_f_util_sections_copy_(gidfrom,gidto,what,gidout);
+}
+int grib_f_util_sections_copy(int* gidfrom,int* gidto,int* what,int *gidout){
+	return grib_f_util_sections_copy_(gidfrom,gidto,what,gidout);
+}
+
 int grib_f_copy_namespace_(int* gidsrc,char* name,int* giddest,int len){
 	char buf[1024]={0,};
 	grib_handle *src  = get_handle(*gidsrc);
@@ -1243,6 +1324,34 @@ int grib_f_new_from_file(int* fid, int* gid){
   return grib_f_new_from_file_( fid, gid);
 }
 
+int grib_f_headers_only_new_from_file_(int* fid, int* gid){
+  int err = 0;
+  FILE* f = get_file(*fid);
+
+  grib_handle *h = NULL;
+
+  if(f){
+    h = grib_handle_headers_only_new_from_file(0,f,&err);
+    if(h){
+      push_handle(h,gid);
+      return GRIB_SUCCESS;
+    } else {
+      *gid=-1;
+      return GRIB_END_OF_FILE;
+    }
+  }
+
+  *gid=-1;
+  return GRIB_INVALID_FILE;
+}
+
+int grib_f_headers_only_new_from_file__(int* fid, int* gid){
+  return grib_f_headers_only_new_from_file_( fid, gid);
+}
+int grib_f_headers_only_new_from_file(int* fid, int* gid){
+  return grib_f_headers_only_new_from_file_( fid, gid);
+}
+
 int grib_f_new_from_index_(int* iid, int* gid){
   int err = 0;
   grib_index* i = get_index(*iid);
@@ -1634,8 +1743,8 @@ int grib_f_index_get_string_(int* gid, char* key, char* val, int *eachsize,int*
     int l=strlen(bufval[i]);
 	int j;
     if (*eachsize < l ) {
-	  grib_context_free(h->context,bufval);
 	  printf("eachsize=%d strlen(bufval[i])=%ld\n",*eachsize,(long)strlen(bufval[i]));
+	  grib_context_free(h->context,bufval);
 	  return GRIB_ARRAY_TOO_SMALL;
 	}
 	memcpy(p,bufval[i],l);
@@ -1929,6 +2038,7 @@ int grib_f_get_real4_array_(int* gid, char* key, float *val, int* size,  int len
   char buf[1024];
   size_t lsize = *size;
   double* val8 = NULL;
+  size_t i;
 
   if(!h) return GRIB_INVALID_GRIB;
 
@@ -1942,8 +2052,8 @@ int grib_f_get_real4_array_(int* gid, char* key, float *val, int* size,  int len
 
   err  = grib_get_double_array(h, cast_char(buf,key,len), val8, &lsize);
 
-  for(*size=0;*size<lsize;(*size)++)
-    val[*size] = val8[*size];
+  for(i=0;i<lsize;i++)
+      val[i] = val8[i];
 
   grib_context_free(h->context,val8);
 
