@@ -1,5 +1,8 @@
 
 /* grib_fortran.c */
+int grib_f_read_any_headers_only_from_file_(int *fid, char *buffer, int *nbytes);
+int grib_f_read_any_headers_only_from_file__(int *fid, char *buffer, int *nbytes);
+int grib_f_read_any_headers_only_from_file(int *fid, char *buffer, int *nbytes);
 int grib_f_read_any_from_file_(int *fid, char *buffer, int *nbytes);
 int grib_f_read_any_from_file__(int *fid, char *buffer, int *nbytes);
 int grib_f_read_any_from_file(int *fid, char *buffer, int *nbytes);
@@ -15,6 +18,7 @@ int grib_f_open_file(int *fid, char *name, char *op, int lname, int lop);
 int grib_f_close_file_(int *fid);
 int grib_f_close_file__(int *fid);
 int grib_f_close_file(int *fid);
+void grib_f_write_on_fail(int *gid);
 int grib_f_multi_support_on_(void);
 int grib_f_multi_support_on__(void);
 int grib_f_multi_support_on(void);
@@ -84,6 +88,9 @@ int grib_f_new_from_template(int *gid, char *name, int lname);
 int grib_f_clone_(int *gidsrc, int *giddest);
 int grib_f_clone__(int *gidsrc, int *giddest);
 int grib_f_clone(int *gidsrc, int *giddest);
+int grib_f_util_sections_copy_(int *gidfrom, int *gidto, int *what, int *gidout);
+int grib_f_util_sections_copy__(int *gidfrom, int *gidto, int *what, int *gidout);
+int grib_f_util_sections_copy(int *gidfrom, int *gidto, int *what, int *gidout);
 int grib_f_copy_namespace_(int *gidsrc, char *name, int *giddest, int len);
 int grib_f_copy_namespace__(int *gidsrc, char *name, int *giddest, int len);
 int grib_f_copy_namespace(int *gidsrc, char *name, int *giddest, int len);
@@ -93,18 +100,21 @@ int grib_f_count_in_file__(int *fid, int *n);
 int grib_f_new_from_file_(int *fid, int *gid);
 int grib_f_new_from_file__(int *fid, int *gid);
 int grib_f_new_from_file(int *fid, int *gid);
+int grib_f_headers_only_new_from_file_(int *fid, int *gid);
+int grib_f_headers_only_new_from_file__(int *fid, int *gid);
+int grib_f_headers_only_new_from_file(int *fid, int *gid);
 int grib_f_new_from_index_(int *iid, int *gid);
 int grib_f_new_from_index__(int *iid, int *gid);
 int grib_f_new_from_index(int *iid, int *gid);
 int grib_f_index_new_from_file_(char *file, char *keys, int *gid, int lfile, int lkeys);
 int grib_f_index_new_from_file__(char *file, char *keys, int *gid, int lfile, int lkeys);
 int grib_f_index_new_from_file(char *file, char *keys, int *gid, int lfile, int lkeys);
-int grib_f_index_read_(char* file, int* gid, int lfile);
-int grib_f_index_read__(char* file, int* gid, int lfile);
-int grib_f_index_read(char* file, int* gid, int lfile);
-int grib_f_index_write_(int* gid, char* file, int lfile);
-int grib_f_index_write__(int* gid, char* file, int lfile);
-int grib_f_index_write(int* gid, char* file, int lfile);
+int grib_f_index_read_(char *file, int *gid, int lfile);
+int grib_f_index_read__(char *file, int *gid, int lfile);
+int grib_f_index_read(char *file, int *gid, int lfile);
+int grib_f_index_write_(int *gid, char *file, int lfile);
+int grib_f_index_write__(int *gid, char *file, int lfile);
+int grib_f_index_write(int *gid, char *file, int lfile);
 int grib_f_index_release_(int *hid);
 int grib_f_index_release__(int *hid);
 int grib_f_index_release(int *hid);
