@@ -17,7 +17,7 @@
 
    START_CLASS_DEF
    CLASS      = action
-   IMPLEMENTS = dump;destroy;xref;execute
+   IMPLEMENTS = dump;destroy;xref;execute;compile
    END_CLASS_DEF
 
  */
@@ -35,6 +35,7 @@ or edit "action.class" and rerun ./make_class.pl
 static void init_class      (grib_action_class*);
 static void dump            (grib_action* d, FILE*,int);
 static void xref            (grib_action* d, FILE* f,const char* path);
+static void compile         (grib_action* a, grib_compiler* compiler);
 static void destroy         (grib_context*,grib_action*);
 static int execute(grib_action* a,grib_handle* h);
 
@@ -62,6 +63,7 @@ static grib_action_class _grib_action_class_noop = {
     0,                            /* notify_change */
     0,                            /* reparse */
     &execute,                            /* execute */
+    &compile,                            /* compile */
 };
 
 grib_action_class* grib_action_class_noop = &_grib_action_class_noop;
@@ -91,6 +93,14 @@ grib_action* grib_action_create_noop( grib_context* context,const char* fname)
   return act;
 }
 
+static void compile(grib_action* act, grib_compiler *compiler)
+{
+    fprintf(compiler->out,"%s = grib_action_create_noop(ctx,",compiler->var);
+    fprintf(compiler->out,"\"%s\"",act->name);
+    fprintf(compiler->out,");");
+    fprintf(compiler->out,"\n");
+}
+
 static void dump(grib_action* act, FILE* f, int lvl)
 {
 }
