@@ -65,6 +65,7 @@ static grib_action_class _grib_action_class_section = {
     &notify_change,                            /* notify_change */
     &reparse,                            /* reparse */
     0,                            /* execute */
+    0,                            /* compile */
 };
 
 grib_action_class* grib_action_class_section = &_grib_action_class_section;
@@ -81,7 +82,6 @@ static void check_sections(grib_section *s,grib_handle* h)
   while(a)
   {
     Assert(a->parent->h == h);
-    /* check_sections(grib_get_sub_section(a),h); */
     check_sections(a->sub_section,h);
     a = a->next;
   }
@@ -109,7 +109,6 @@ static int notify_change(grib_action* act, grib_accessor * notified,
       act->name, notified->name, changed->name);
 
   la = grib_action_reparse(act,notified,&doit);
-  /* old_section = grib_get_sub_section(notified); */
   old_section = notified->sub_section;
   Assert(old_section);
 
@@ -185,9 +184,7 @@ static int notify_change(grib_action* act, grib_accessor * notified,
 
   grib_swap_sections(old_section,
       tmp_handle->root->block->first->sub_section);
-      /* grib_get_sub_section(tmp_handle->root->block->first)); */
 
-  /* check_sections(old_section,h); */
   Assert(tmp_handle->dependencies == NULL);
   /* printf("grib_handle_delete %p\n",(void*)tmp_handle); */
 
@@ -213,7 +210,6 @@ static int notify_change(grib_action* act, grib_accessor * notified,
   grib_update_paddings(old_section);
 
 
-  /* check_sections(h->root,h); */
   return err;
 }
 
