@@ -72,6 +72,7 @@ static grib_action_class _grib_action_class_switch = {
     0,                            /* notify_change */
     0,                            /* reparse */
     &execute,                            /* execute */
+    0,                            /* compile */
 };
 
 grib_action_class* grib_action_class_switch = &_grib_action_class_switch;
@@ -82,6 +83,7 @@ static void init_class(grib_action_class* c)
 	c->create_accessor	=	(*(c->super))->create_accessor;
 	c->notify_change	=	(*(c->super))->notify_change;
 	c->reparse	=	(*(c->super))->reparse;
+	c->compile	=	(*(c->super))->compile;
 }
 /* END_CLASS_IMP */
 
