@@ -66,6 +66,7 @@ static grib_action_class _grib_action_class_while = {
     0,                            /* notify_change */
     0,                            /* reparse */
     0,                            /* execute */
+    0,                            /* compile */
 };
 
 grib_action_class* grib_action_class_while = &_grib_action_class_while;
@@ -76,6 +77,7 @@ static void init_class(grib_action_class* c)
 	c->notify_change	=	(*(c->super))->notify_change;
 	c->reparse	=	(*(c->super))->reparse;
 	c->execute	=	(*(c->super))->execute;
+	c->compile	=	(*(c->super))->compile;
 }
 /* END_CLASS_IMP */
 
@@ -101,7 +103,6 @@ static int create_accessor(grib_section* p, grib_action* act,grib_loader* h)
 
 	ga = grib_accessor_factory(p, act,0,NULL);
 	if(!ga)  return GRIB_BUFFER_TOO_SMALL;
-	/* gs = grib_get_sub_section(ga); */
 	gs = ga->sub_section;
 
 	grib_push_accessor(ga,p->block);   
