@@ -118,6 +118,7 @@ static grib_accessor_class _grib_accessor_class_data_complex_packing = {
     0,                       /* next accessor    */
     0,                    /* compare vs. another accessor   */
     0,     /* unpack only ith value          */
+    0,     /* unpack a subarray         */
     0,             		/* clear          */
 };
 
@@ -150,6 +151,7 @@ static void init_class(grib_accessor_class* c)
 	c->next	=	(*(c->super))->next;
 	c->compare	=	(*(c->super))->compare;
 	c->unpack_double_element	=	(*(c->super))->unpack_double_element;
+	c->unpack_double_subarray	=	(*(c->super))->unpack_double_subarray;
 	c->clear	=	(*(c->super))->clear;
 }
 
@@ -409,10 +411,8 @@ static int  unpack_double(grib_accessor* a, double* val, size_t *len)
 }
 
 
-static double calc_max(double a,double b){
-  if(a>b) return a;
-  return b;
-}
+
+#define MAXVAL(a,b) a>b?a:b
 
 static double calculate_pfactor(grib_context *ctx,const double* spectralField, long fieldTruncation, long subsetTruncation)
 {
@@ -449,12 +449,8 @@ static double calculate_pfactor(grib_context *ctx,const double* spectralField, l
     for( n = m; n <= fieldTruncation; n++ ) {
       index += 2;
       if( n >= subsetTruncation ) {
-        double tval = spectralField[index];
-        tval=tval<0?-tval:tval;
-        norms[n] = calc_max(norms[n],tval);
-        tval = spectralField[index+1];
-        tval=tval<0?-tval:tval;
-        norms[n] = calc_max(norms[n],tval);
+        norms[n] = MAXVAL(norms[n],fabs(spectralField[index]));
+        norms[n] = MAXVAL(norms[n],fabs(spectralField[index+1]));
       }
     }
   /*
@@ -463,13 +459,9 @@ static double calculate_pfactor(grib_context *ctx,const double* spectralField, l
 
   for( m = subsetTruncation; m <= fieldTruncation; m++ )
     for( n = m; n <= fieldTruncation; n++ ) {
-      double tval = spectralField[index];
       index += 2;
-      tval=tval<0?-tval:tval;
-      norms[n] = calc_max(norms[n],tval);
-      tval = spectralField[index+1];
-      tval=tval<0?-tval:tval;
-      norms[n] = calc_max(norms[n],tval);
+      norms[n] = MAXVAL(norms[n],fabs(spectralField[index]));
+      norms[n] = MAXVAL(norms[n],fabs(spectralField[index+1]));
     }
 
   /*
@@ -478,7 +470,7 @@ static double calculate_pfactor(grib_context *ctx,const double* spectralField, l
    */
 
   for( loop = ismin; loop <= ismax; loop++ ) {
-    norms[n] = calc_max(norms[n],zeps);
+    norms[n] = MAXVAL(norms[n],zeps);
     if( norms[n] == zeps ) weights[n] = 100.0 * zeps;
   }
 
@@ -517,7 +509,6 @@ static double calculate_pfactor(grib_context *ctx,const double* spectralField, l
   pFactor = -slope;
   if( pFactor < -9999.9 ) pFactor = -9999.9;
   if( pFactor > 9999.9 )  pFactor = 9999.9;
-
   return pFactor;
 }
 
