@@ -17,6 +17,7 @@
    SUPER      = grib_accessor_class_data_simple_packing
    IMPLEMENTS = init
    IMPLEMENTS = pack_double
+   IMPLEMENTS = pack_bytes 
    IMPLEMENTS = value_count
    END_CLASS_DEF
 
@@ -32,6 +33,7 @@ or edit "accessor.class" and rerun ./make_class.pl
 
 */
 
+static int pack_bytes(grib_accessor*,const unsigned char*, size_t *len);
 static int pack_double(grib_accessor*, const double* val,size_t *len);
 static long value_count(grib_accessor*);
 static void init(grib_accessor*,const long, grib_arguments* );
@@ -84,7 +86,7 @@ static grib_accessor_class _grib_accessor_class_data_g2simple_packing = {
     0,              /* grib_unpack procedures double  */
     0,                /* grib_pack procedures string    */
     0,              /* grib_unpack procedures string  */
-    0,                 /* grib_pack procedures bytes     */
+    &pack_bytes,                 /* grib_pack procedures bytes     */
     0,               /* grib_unpack procedures bytes   */
     0,            /* pack_expression */
     0,              /* notify_change   */
@@ -95,6 +97,7 @@ static grib_accessor_class _grib_accessor_class_data_g2simple_packing = {
     0,                       /* next accessor    */
     0,                    /* compare vs. another accessor   */
     0,     /* unpack only ith value          */
+    0,     /* unpack a subarray         */
     0,             		/* clear          */
 };
 
@@ -117,7 +120,6 @@ static void init_class(grib_accessor_class* c)
 	c->unpack_double	=	(*(c->super))->unpack_double;
 	c->pack_string	=	(*(c->super))->pack_string;
 	c->unpack_string	=	(*(c->super))->unpack_string;
-	c->pack_bytes	=	(*(c->super))->pack_bytes;
 	c->unpack_bytes	=	(*(c->super))->unpack_bytes;
 	c->pack_expression	=	(*(c->super))->pack_expression;
 	c->notify_change	=	(*(c->super))->notify_change;
@@ -128,6 +130,7 @@ static void init_class(grib_accessor_class* c)
 	c->next	=	(*(c->super))->next;
 	c->compare	=	(*(c->super))->compare;
 	c->unpack_double_element	=	(*(c->super))->unpack_double_element;
+	c->unpack_double_subarray	=	(*(c->super))->unpack_double_subarray;
 	c->clear	=	(*(c->super))->clear;
 }
 
@@ -203,7 +206,6 @@ static int pack_double(grib_accessor* a, const double* cval, size_t *len)
     case GRIB_CONSTANT_FIELD:
       grib_buffer_replace(a, NULL, 0,1,1);
       return GRIB_SUCCESS;
-      break;
     case GRIB_SUCCESS:
       break;
     default:
@@ -246,3 +248,10 @@ static int pack_double(grib_accessor* a, const double* cval, size_t *len)
   return ret;
 }
 
+static int pack_bytes(grib_accessor* a, const unsigned char* val, size_t *len)
+{
+  size_t length = *len;
+  grib_buffer_replace(a, val, length,1,1);
+  return GRIB_SUCCESS;
+}
+
