@@ -22,6 +22,7 @@
    IMPLEMENTS = init
    IMPLEMENTS = unpack_double
    IMPLEMENTS = unpack_double_element
+   IMPLEMENTS = unpack_double_subarray
    IMPLEMENTS = pack_double
    IMPLEMENTS = value_count
    MEMBERS=const char*  units_factor
@@ -52,6 +53,7 @@ static long value_count(grib_accessor*);
 static void init(grib_accessor*,const long, grib_arguments* );
 static void init_class(grib_accessor_class*);
 static int unpack_double_element(grib_accessor*,size_t i, double* val);
+static int unpack_double_subarray(grib_accessor*, double* val,size_t start,size_t len);
 
 typedef struct grib_accessor_data_simple_packing {
     grib_accessor          att;
@@ -110,6 +112,7 @@ static grib_accessor_class _grib_accessor_class_data_simple_packing = {
     0,                       /* next accessor    */
     0,                    /* compare vs. another accessor   */
     &unpack_double_element,     /* unpack only ith value          */
+    &unpack_double_subarray,     /* unpack a subarray         */
     0,             		/* clear          */
 };
 
@@ -267,26 +270,22 @@ static int  unpack_double_element(grib_accessor* a, size_t idx, double* val)
   return err;
 }
 
-static int  unpack_double(grib_accessor* a, double* val, size_t *len)
+static int  _unpack_double(grib_accessor* a, double* val, size_t *len,unsigned char* buf,long pos, size_t n_vals)
 {
   grib_accessor_data_simple_packing* self =  (grib_accessor_data_simple_packing*)a;
 
   size_t i = 0;
-  size_t n_vals;
   int err = 0;
 
   double reference_value;
   long   binary_scale_factor;
   long   bits_per_value;
   long   decimal_scale_factor;
-  unsigned char* buf = (unsigned char*)a->parent->h->buffer->data;
   double s = 0;
   double d = 0;
-  long pos = 0;
   double units_factor=1.0;
   double units_bias=0.0;
 
-  n_vals = grib_value_count(a);
 
   if(*len < n_vals)
   {
@@ -375,6 +374,32 @@ static int  unpack_double(grib_accessor* a, double* val, size_t *len)
   return err;
 }
 
+static int  unpack_double_subarray(grib_accessor* a, double* val, size_t start, size_t len)
+{
+  grib_accessor_data_simple_packing* self =  (grib_accessor_data_simple_packing*)a;
+  unsigned char* buf = (unsigned char*)a->parent->h->buffer->data;
+  size_t nvals = len;
+  size_t *plen=&len;
+  long bits_per_value=0;
+  long pos;
+  int err;
+
+  if((err = grib_get_long_internal(a->parent->h,self->bits_per_value,&bits_per_value)) !=
+       GRIB_SUCCESS)
+    return err;
+
+  buf+=(start*bits_per_value)/8;
+  pos=start*bits_per_value%8;
+  return _unpack_double(a,val,plen,buf,pos,nvals);
+}
+
+static int  unpack_double(grib_accessor* a, double* val, size_t *len) {
+  unsigned char* buf = (unsigned char*)a->parent->h->buffer->data;
+  size_t nvals = grib_value_count(a);
+  long pos=0;
+  return _unpack_double(a,val,len,buf,pos,nvals);
+}
+
 
 static int pack_double(grib_accessor* a, const double* val, size_t *len)
 {
@@ -383,10 +408,12 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
   size_t i = 0;
   size_t n_vals = *len;
   int err = 0;
+  int last;
   double reference_value = 0;
   long   binary_scale_factor = 0;
   long   bits_per_value = 0;
   long   decimal_scale_factor = 0;
+  long   decimal_scale_factor_get = 0;
   double decimal = 1;
   double max = 0;
   double min = 0;
@@ -399,18 +426,19 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
   long changing_precision=0;
   grib_context* c=a->parent->h->context;
 
+  decimal_scale_factor=0;
+
   if (*len ==0) return GRIB_NO_VALUES;
 
   if((err = grib_get_long_internal(a->parent->h,self->bits_per_value,&bits_per_value)) !=
       GRIB_SUCCESS)
     return err;
 
-  if((err = grib_get_long_internal(a->parent->h,self->decimal_scale_factor, &decimal_scale_factor))
-     != GRIB_SUCCESS)
-    return err;
-
   if(*len == 0) return GRIB_SUCCESS;
 
+  if((err = grib_get_long_internal(a->parent->h,self->decimal_scale_factor, &decimal_scale_factor_get))
+     != GRIB_SUCCESS)
+     return err;
   /*/
    * check we don't encode bpv > max(ulong)-1 as it is 
    * not currently supported by the algorithm 
@@ -427,39 +455,46 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
     if (val[i] > max ) max = val[i];
     if (val[i] < min ) min = val[i];
   }
-  decimal = grib_power(decimal_scale_factor,10) ;
-  unscaled_min=min;
-  unscaled_max=max;
-  min*=decimal;
-  max*=decimal;
 
   /* constant field only reference_value is set and bits_per_value=0 */
-  if(max == min && c->gribex_mode_on==0) {
-    if (grib_get_nearest_smaller_value(a->parent->h,self->reference_value,val[0],&reference_value)
-        !=GRIB_SUCCESS) {
-        grib_context_log(a->parent->h->context,GRIB_LOG_ERROR,
-         "unable to find nearest_smaller_value of %g for %s",min,self->reference_value);
-        exit(GRIB_INTERNAL_ERROR);
-    }
-    if((err = grib_set_double_internal(a->parent->h,self->reference_value, reference_value)) !=
-      GRIB_SUCCESS)
-      return err;
+  if(max==min) {
+	if (grib_get_nearest_smaller_value(a->parent->h,self->reference_value,val[0],&reference_value)
+		!=GRIB_SUCCESS) {
+		grib_context_log(a->parent->h->context,GRIB_LOG_ERROR,
+		 "unable to find nearest_smaller_value of %g for %s",min,self->reference_value);
+		exit(GRIB_INTERNAL_ERROR);
+	}
+	if((err = grib_set_double_internal(a->parent->h,self->reference_value, reference_value)) !=
+	  GRIB_SUCCESS)
+	  return err;
 
-    bits_per_value=0;
-    if((err = grib_set_long_internal(a->parent->h,self->bits_per_value, bits_per_value)) !=
-      GRIB_SUCCESS)
-      return err;
-
-    {
-      /* Make sure we can decode it again */
-      double ref = 1e-100;
-      grib_get_double_internal(a->parent->h,self->reference_value,&ref);
+	{
+	  /* Make sure we can decode it again */
+	  double ref = 1e-100;
+	  grib_get_double_internal(a->parent->h,self->reference_value,&ref);
 	  if (ref != reference_value) 
-	    printf("%.20e  !=  %.20e",ref,reference_value);
-      Assert(ref == reference_value);
-    }
+		printf("%.20e  !=  %.20e",ref,reference_value);
+	  Assert(ref == reference_value);
+	}
 
-     return GRIB_CONSTANT_FIELD;
+	if (c->gribex_mode_on==0) {
+		bits_per_value=0;
+		if((err = grib_set_long_internal(a->parent->h,self->bits_per_value, bits_per_value)) !=
+		  GRIB_SUCCESS)
+		  return err;
+
+		 return GRIB_CONSTANT_FIELD;
+	 } else {
+		if((err = grib_set_long_internal(a->parent->h,self->binary_scale_factor, 0)) !=
+		  GRIB_SUCCESS)
+		  return err;
+
+		if((err = grib_set_long_internal(a->parent->h,self->decimal_scale_factor, 0)) !=
+		  GRIB_SUCCESS)
+		  return err;
+
+	 	return GRIB_SUCCESS;
+	 }
   }
 
   if((err = grib_get_long_internal(a->parent->h,self->binary_scale_factor, &binary_scale_factor))
@@ -472,7 +507,8 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
 
   /* the packing parameters are not properly defined
   this is a safe way of fixing the problem */
-  if ( changing_precision==0 && bits_per_value==0 && decimal_scale_factor==0) {
+  if ( changing_precision==0 && bits_per_value==0  && decimal_scale_factor_get==0) {
+
     grib_context_log(a->parent->h->context,GRIB_LOG_WARNING,
                      "%s==0 and %s==0 (setting %s=24)",
                      self->bits_per_value,
@@ -486,9 +522,14 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
   }
 
   if ( bits_per_value == 0 ) {
-    binary_scale_factor=0;
     /* decimal_scale_factor is given, binary_scale_factor=0
        and bits_per_value is computed */
+    binary_scale_factor=0;
+	decimal_scale_factor=decimal_scale_factor_get;
+    decimal = grib_power(decimal_scale_factor,10) ;
+    min*=decimal;
+    max*=decimal;
+
     imin=(long)rint(min);
     imax=(long)rint(max);
     bits_per_value=(long)ceil(log((double)(imax-imin+1))/log(2.0));
@@ -504,7 +545,8 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
     }
     /* divisor=1; */
   } else {
-    int last=127;
+    last=127;
+	if (c->gribex_mode_on) last=99;
     /* bits_per_value is given and decimal_scale_factor
        and binary_scale_factor are calcualated
     */
@@ -522,6 +564,8 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
             max,reference_value,grib_power(-last,2),decimal_scale_factor,bits_per_value);*/
       /* last must be a parameter coming from the def file*/
       range=(max-min);
+	  unscaled_min=min;
+	  unscaled_max=max;
       f=(grib_power(bits_per_value,2)-1);
       minrange=grib_power(-last,2)*f;
       maxrange=grib_power(last,2)*f;
@@ -557,18 +601,6 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
       GRIB_SUCCESS)
     return err;
 
-  {
-    /* Make sure we can decode it again */
-    double ref = 1e-100;
-    grib_get_double_internal(a->parent->h,self->reference_value,&ref);
-    if(ref!=reference_value)
-    {
-      printf("ref=%g reference_value=%g diff=%g\n",
-             ref,reference_value,ref-reference_value);
-      Assert(ref == reference_value);
-    }
-  }
-
   if((err = grib_set_long_internal(a->parent->h,self->changing_precision, 0)) !=
      GRIB_SUCCESS)
     return err;
