@@ -108,6 +108,7 @@ static grib_accessor_class _grib_accessor_class_g1step_range = {
     0,                       /* next accessor    */
     0,                    /* compare vs. another accessor   */
     0,     /* unpack only ith value          */
+    0,     /* unpack a subarray         */
     0,             		/* clear          */
 };
 
@@ -136,6 +137,7 @@ static void init_class(grib_accessor_class* c)
 	c->next	=	(*(c->super))->next;
 	c->compare	=	(*(c->super))->compare;
 	c->unpack_double_element	=	(*(c->super))->unpack_double_element;
+	c->unpack_double_subarray	=	(*(c->super))->unpack_double_subarray;
 	c->clear	=	(*(c->super))->clear;
 }
 
@@ -169,22 +171,50 @@ static void dump(grib_accessor* a, grib_dumper* dumper)
 
 }
 
-static int u2s[] =  {
-	60,      /* (0) minutes */
-	3600,    /* (1) hour    */
-	86400,   /* (2) day     */
-    2592000,   /* (3) month   */
-	-1, -1, -1, -1, -1,-1,
-	10800,   /* (10) 3 hours */
-	21600,   /* (11) 6 hours */
-	43200,   /* (12) 12 hours */
-	1        /* (13) seconds  */
+
+static int u2s1[] =  {
+  60,      /* (0) minutes */
+  3600,    /* (1) hour    */
+  86400,   /* (2) day     */
+  2592000, /* (3) month     */
+  -1,      /* (4) */
+  -1,      /* (5) */
+  -1,      /* (6) */
+  -1,      /* (7) */
+  -1,      /* (8) */
+  -1,      /* (9) */
+  10800,   /* (10) 3 hours */
+  21600,   /* (11) 6 hours */
+  43200,   /* (12) 12 hours */
+  900,     /* (13) 15 minutes  */
+  1800,    /* (14) 30 minutes */
+  1        /* (15) seconds  */
 };
 
 static int units_index[] = {
-	1,0,10,11,12,2,13,0
+	1,0,10,11,12,2,0,13,14,15
 };
 
+static int u2s[] =  {
+  60,      /* (0) minutes */
+  3600,    /* (1) hour    */
+  86400,   /* (2) day     */
+  2592000, /* (3) month     */
+  -1,      /* (4) */
+  -1,      /* (5) */
+  -1,      /* (6) */
+  -1,      /* (7) */
+  -1,      /* (8) */
+  -1,      /* (9) */
+  10800,   /* (10) 3 hours */
+  21600,   /* (11) 6 hours */
+  43200,   /* (12) 12 hours */
+  1,       /* (13) seconds  */
+  900,     /* (14) 15 minutes  */
+  1800     /* (15) 30 minutes  */
+};
+
+
 int grib_g1_step_get_steps(grib_accessor* a,long* start,long* end) {
 	grib_accessor_g1step_range* self = (grib_accessor_g1step_range*)a;
 	int err = 0;
@@ -193,6 +223,8 @@ int grib_g1_step_get_steps(grib_accessor* a,long* start,long* end) {
 	char stepType[20]={0,};
     size_t stepTypeLen=20;
 	long newstart,newend;
+	int factor=1;
+	long u2sf,u2sf_step_unit;
 
 	if (self->step_unit != NULL)
 		grib_get_long_internal(a->parent->h,self->step_unit,&step_unit);
@@ -228,14 +260,32 @@ int grib_g1_step_get_steps(grib_accessor* a,long* start,long* end) {
 	else if (!strcmp(stepType,"instant")) *start = *end = p1;
     else if (!strcmp(stepType,"accum") && timeRangeIndicator==0 ) {*start =0; *end = p1;}
 
-	if(*start > *end) *end = *start;
+	if(*start > *end) {
+		/* Special case for Aladin, where P1 is missing in accumulation */
+		if(!(*start == 255 && *end == 0 && timeRangeIndicator==2)) 
+		{
+			*end = *start;
+		}
+	}
 
-	if (u2s[unit] == u2s[step_unit] || (*start==0 && *end==0) ) return 0;
+	if (u2s1[unit] == u2s[step_unit] || (*start==0 && *end==0) ) return 0;
 
-	newstart = (*start) * u2s[unit];
-	newend   = (*end)   * u2s[unit];
+	newstart = (*start) * u2s1[unit];
+	newend   = (*end)   * u2s1[unit];
 
-	if (newstart % u2s[step_unit] != 0 || newend % u2s[step_unit] != 0) {
+	if (newstart<0 || newend<0) {
+		factor=60;
+		u2sf=u2s1[unit]/factor;
+		if (u2s1[unit] % factor) return GRIB_DECODING_ERROR;
+		newstart = (*start) * u2sf;
+		newend   = (*end)   * u2sf;
+		u2sf_step_unit=u2s[step_unit]/factor;
+		if (u2s[step_unit] % factor) return GRIB_DECODING_ERROR;
+	} else {
+		u2sf_step_unit=u2s[step_unit];
+	}
+
+	if (newstart % u2sf_step_unit != 0 || newend % u2sf_step_unit != 0) {
 		size_t step_unit_string_len=10;
 		char step_unit_string[10];
 		if (self->step_unit != NULL)
@@ -245,13 +295,14 @@ int grib_g1_step_get_steps(grib_accessor* a,long* start,long* end) {
 
 		err = grib_set_long_internal(a->parent->h,self->step_unit,unit);
 		
-		grib_context_log(a->parent->h->context,GRIB_LOG_WARNING,
+		grib_context_log(a->parent->h->context,GRIB_LOG_ERROR,
 				"unable to represent the step in %s",
 				step_unit_string);
+		return GRIB_DECODING_ERROR;
 	
 	} else {
-		*start = newstart/u2s[step_unit];
-		*end   = newend/u2s[step_unit];
+		*start = newstart/u2sf_step_unit;
+		*end   = newend/u2sf_step_unit;
 	}
 
 	return 0;
@@ -306,8 +357,9 @@ int grib_g1_step_apply_units(long *start,long *end,long* step_unit,
 	int j=0;
 	long start_sec,end_sec;
     int index=0;
+	int max_index=sizeof(units_index)/sizeof(*units_index);
 
-    while (*unit != units_index[index] && index!=8)
+    while (*unit != units_index[index] && index!=max_index)
       index++;
 
 	start_sec=*start*u2s[*step_unit];
@@ -315,15 +367,15 @@ int grib_g1_step_apply_units(long *start,long *end,long* step_unit,
 
 	if (instant) {
 		*unit=units_index[0];
-		for (j=index;j<8;j++) {
-			if ( start_sec%u2s[*unit]==0 &&
-					(*P1=start_sec/u2s[*unit])<=max)
+		for (j=index;j<max_index;j++) {
+			if ( start_sec % u2s1[*unit]==0 &&
+					(*P1=start_sec/u2s1[*unit])<=max)
 				return 0;
 			*unit=units_index[j];
 		}
         for (j=0;j<index;j++) {
-          if ( start_sec%u2s[*unit]==0 &&
-               (*P1=start_sec/u2s[*unit])<=max)
+          if ( start_sec%u2s1[*unit]==0 &&
+               (*P1=start_sec/u2s1[*unit])<=max)
             return 0;
           *unit=units_index[j];
         }
@@ -331,19 +383,19 @@ int grib_g1_step_apply_units(long *start,long *end,long* step_unit,
 	} else {
 		end_sec=*end*u2s[*step_unit];
 		*unit=units_index[0];
-		for (j=index;j<8;j++) {
-			if ( start_sec%u2s[*unit]==0 &&
-					end_sec%u2s[*unit]==0 &&
-					(*P1=start_sec/u2s[*unit])<=max &&
-					(*P2=end_sec/u2s[*unit])<=max )
+		for (j=index;j<max_index;j++) {
+			if ( start_sec%u2s1[*unit]==0 &&
+					end_sec%u2s1[*unit]==0 &&
+					(*P1=start_sec/u2s1[*unit])<=max &&
+					(*P2=end_sec/u2s1[*unit])<=max )
 				return 0;
 			*unit=units_index[j];
 		}
         for (j=0;j<index;j++) {
-          if ( start_sec%u2s[*unit]==0 &&
-               end_sec%u2s[*unit]==0 &&
-               (*P1=start_sec/u2s[*unit])<=max &&
-               (*P2=end_sec/u2s[*unit])<=max )
+          if ( start_sec%u2s1[*unit]==0 &&
+               end_sec%u2s1[*unit]==0 &&
+               (*P1=start_sec/u2s1[*unit])<=max &&
+               (*P2=end_sec/u2s1[*unit])<=max )
             return 0;
           *unit=units_index[j];
         }
