@@ -85,6 +85,7 @@ static grib_accessor_class _grib_accessor_class_g2bitmap_present = {
     0,                       /* next accessor    */
     0,                    /* compare vs. another accessor   */
     0,     /* unpack only ith value          */
+    0,     /* unpack a subarray         */
     0,             		/* clear          */
 };
 
@@ -118,6 +119,7 @@ static void init_class(grib_accessor_class* c)
 	c->next	=	(*(c->super))->next;
 	c->compare	=	(*(c->super))->compare;
 	c->unpack_double_element	=	(*(c->super))->unpack_double_element;
+	c->unpack_double_subarray	=	(*(c->super))->unpack_double_subarray;
 	c->clear	=	(*(c->super))->clear;
 }
 
@@ -139,9 +141,13 @@ static int  unpack_long(grib_accessor* a, long* val, size_t *len)
 
   grib_accessor_g2bitmap_present* self = (grib_accessor_g2bitmap_present*)a;
 
-  if((ret = grib_get_long_internal(a->parent->h, self->bitmapIndicator,&bitmapIndicator))
-      != GRIB_SUCCESS)
-    return ret;
+  ret = grib_get_long_internal(a->parent->h, self->bitmapIndicator,&bitmapIndicator);
+  if (ret) {
+  	if (ret==GRIB_NOT_FOUND) {
+		*val=0;
+		return 0;
+	} else return ret;
+  }
 
   *val=1;
   if (bitmapIndicator==255) *val=0;
