@@ -25,9 +25,18 @@ extern "C" {
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/times.h>
 
 #define GRIB_API_VERSION (GRIB_API_MAJOR_VERSION*10000+GRIB_API_MINOR_VERSION*100+GRIB_API_REVISION_VERSION)
 
+/* sections */
+#define GRIB_SECTION_PRODUCT 	(1<<0)
+#define GRIB_SECTION_GRID 		(1<<1)
+#define GRIB_SECTION_LOCAL 		(1<<2)
+#define GRIB_SECTION_DATA 		(1<<3)
+#define GRIB_SECTION_BITMAP		(1<<4)
+
+
 /* LOG MODES
 Log mode for information for processiong information
 */
@@ -65,6 +74,8 @@ Log mode for information for processiong information
 #define GRIB_MISSING_LONG 0xffffffff
 #define GRIB_MISSING_DOUBLE -1e+100
 
+/*set spec flags*/
+#define GRIB_UTIL_SET_SPEC_FLAGS_ONLY_PACKING	(1<<0)
 
 /* Dump option flags*/
 #define GRIB_DUMP_FLAG_READ_ONLY    (1<<0)
@@ -141,6 +152,7 @@ struct grib_values {
   grib_values* next;
 } ;
 
+
 /*! Grib handle,   structure giving access to parsed grib values by keys
     \ingroup grib_handle
 */
@@ -166,6 +178,12 @@ typedef struct grib_iterator  grib_iterator;
 */
 typedef struct grib_nearest  grib_nearest;
 
+/*! Grib box, structure used to crop a box given north/west/south/east boundaries.
+    \ingroup grib_box
+*/
+typedef struct grib_box  grib_box;
+typedef struct grib_points  grib_points;
+
 /*! Grib keys iterator. Iterator over keys.
     \ingroup keys_iterator
 */
@@ -189,6 +207,7 @@ void grib_fieldset_rewind(grib_fieldset* set);
 int grib_fieldset_apply_order_by(grib_fieldset* set,const char* order_by_string);
 grib_handle* grib_fieldset_next_handle(grib_fieldset* set,int* err);
 int grib_fieldset_count(grib_fieldset *set);
+int grib_values_check(grib_handle* h, grib_values* values, int count);
 
 /*! \defgroup grib_index The grib_index
 The grib_index is the structure giving indexed access to messages in a file.
@@ -367,6 +386,40 @@ int grib_count_in_file(grib_context* c, FILE* f,int* n);
 * @return            the new handle, NULL if the resource is invalid or a problem is encountered
 */
 grib_handle* grib_handle_new_from_file     (grib_context* c, FILE* f, int* error)        ;
+grib_handle* grib_handle_headers_only_new_from_file     (grib_context* c, FILE* f, int* error)        ;
+
+/**
+*  Create a handle from a file resource.
+*  The file is supposed to contain a netCDF message. 
+*  Remember always to delete the handle when it is not needed any more to avoid
+*  memory leaks.
+*
+* @param c           : the context from wich the handle will be created (NULL for default context)
+* @param file        : the file name
+* @param error       : error code set if the returned handle is NULL and the end of file is not reached
+* @return            the new handle, NULL if the resource is invalid or a problem is encountered
+*/
+grib_handle* grib_handle_new_from_nc_file(grib_context* c,const char* file,int *error);
+
+/**
+*  Write a coded message in a file.     
+*
+* @param h           : grib_handle to be written
+* @param file        : name of the file 
+* @param mode        : mode 
+* @return            0 if OK, integer value on error
+*/
+int grib_write_message(grib_handle* h,const char* file,const char* mode);
+
+typedef struct grib_string_list grib_string_list;
+struct grib_string_list {
+  char* value;
+  grib_string_list* next;
+};
+
+grib_handle* grib_util_sections_copy(grib_handle* hfrom,grib_handle* hto,int what,int *err);
+grib_string_list* grib_util_get_param_id(const char* mars_param);
+grib_string_list* grib_util_get_mars_param(const char* param_id);
 
 /**
 *  Create a handle from a user message in memory. The message will not be freed at the end.
@@ -1007,7 +1060,7 @@ void             grib_context_delete                     (grib_context* c);
 *  Set the gts header mode on.
 *  The GTS headers will be preserved.
 *
-* @param c           : the context to be deleted
+* @param c           : the context
 */
 void grib_gts_header_on(grib_context* c) ;
 
@@ -1015,7 +1068,7 @@ void grib_gts_header_on(grib_context* c) ;
 *  Set the gts header mode off.
 *  The GTS headers will be deleted.
 *
-* @param c           : the context to be deleted
+* @param c           : the context
 */
 void grib_gts_header_off(grib_context* c);
 
@@ -1023,15 +1076,22 @@ void grib_gts_header_off(grib_context* c);
 *  Set the gribex mode on.
 *  Grib files will be compatible with gribex.
 *
-* @param c           : the context to be deleted
+* @param c           : the context
 */
 void grib_gribex_mode_on(grib_context* c);
 
+/**
+*  Get the gribex mode.
+*
+* @param c           : the context
+*/
+int grib_get_gribex_mode ( grib_context* c);
+
 /**
 *  Set the gribex mode off.
 *  Grib files won't be always compatible with gribex.
 *
-* @param c           : the context to be deleted
+* @param c           : the context
 */
 void grib_gribex_mode_off(grib_context* c);
 
@@ -1228,6 +1288,137 @@ int wmo_read_any_from_file(FILE *f, void *buffer, size_t *len);
 int wmo_read_any_from_stream(void *stream_data, long (*stream_proc )(void *, void *buffer, long len ), void *buffer, size_t *len);
 void *wmo_read_any_from_file_malloc(FILE *f, int *err);
 
+struct grib_points {
+    grib_context* context;
+    double* latitudes;
+    double* longitudes;
+    size_t* indexes;
+    size_t* group_start;
+    size_t* group_len;
+    size_t n_groups;
+    size_t n;
+    size_t size;
+};
+
+grib_box* grib_box_new(grib_handle* h,int* error);
+grib_points* grib_box_get_points(grib_box *box,double north, double west,double south,double east, int *err);
+int grib_points_get_values(grib_handle* h, grib_points* points, double* val);
+
+
+/* --------------------------------------- */
+
+
+
+
+#define GRIB_UTIL_GRID_SPEC_REGULAR_LL 1
+#define GRIB_UTIL_GRID_SPEC_ROTATED_LL 2
+
+#define GRIB_UTIL_GRID_SPEC_REGULAR_GG 3
+#define GRIB_UTIL_GRID_SPEC_ROTATED_GG 4
+#define GRIB_UTIL_GRID_SPEC_REDUCED_GG 5
+
+#define GRIB_UTIL_GRID_SPEC_SH         6
+#define GRIB_UTIL_GRID_SPEC_REDUCED_LL 7
+#define GRIB_UTIL_GRID_SPEC_POLAR_STEREOGRAPHIC 8
+
+
+typedef struct grib_util_grid_spec {
+
+	int grid_type;
+
+	/* Grid */
+	long   Ni;
+	long   Nj;
+
+	double iDirectionIncrementInDegrees;
+	double jDirectionIncrementInDegrees;
+
+	double longitudeOfFirstGridPointInDegrees;
+	double longitudeOfLastGridPointInDegrees;
+
+	double latitudeOfFirstGridPointInDegrees;
+	double latitudeOfLastGridPointInDegrees;
+
+	/* Rotation */
+	long uvRelativeToGrid;
+	double latitudeOfSouthernPoleInDegrees;
+	double longitudeOfSouthernPoleInDegrees;
+
+	/* Scanning mode */
+	long iScansNegatively;
+	long jScansPositively;
+
+	/* Gaussian number */
+	long N;
+
+	/* bitmap */
+	long bitmapPresent;
+	double missingValue;
+
+	/* pl list for reduced */
+	long *pl;
+	long pl_size;
+
+	/* Spherical harmonics */
+	long truncation;
+
+	/* polar stereographic */
+	double orientationOfTheGridInDegrees;
+	long DyInMetres;
+	long DxInMetres;
+
+} grib_util_grid_spec;
+
+
+#define GRIB_UTIL_PACKING_TYPE_SPECTRAL_COMPLEX 1
+#define GRIB_UTIL_PACKING_TYPE_SPECTRAL_SIMPLE    2
+#define GRIB_UTIL_PACKING_TYPE_JPEG    3
+#define GRIB_UTIL_PACKING_TYPE_GRID_COMPLEX    4
+#define GRIB_UTIL_PACKING_TYPE_GRID_SIMPLE    5
+
+#define GRIB_UTIL_PACKING_SAME_AS_INPUT    	0
+#define GRIB_UTIL_PACKING_USE_PROVIDED  	1
+
+#define GRIB_UTIL_ACCURACY_SAME_BITS_PER_VALUES_AS_INPUT      0 
+#define GRIB_UTIL_ACCURACY_USE_PROVIDED_BITS_PER_VALUES       1
+#define GRIB_UTIL_ACCURACY_SAME_DECIMAL_SCALE_FACTOR_AS_INPUT 2
+#define GRIB_UTIL_ACCURACY_USE_PROVIDED_DECIMAL_SCALE_FACTOR  3
+
+typedef struct grib_util_packing_spec {
+
+	/* Packing options */
+	long packing_type;
+	long packing;      
+
+	long editionNumber; /* =0 for default value */
+
+	/* Accuracy */
+	long accuracy; 
+	long bitsPerValue;          
+	long decimalScaleFactor;  
+
+	long computeLaplacianOperator;
+
+	/* local definition */
+	long deleteLocalDefinition; /* default(=0) local definition is taken from the input field */
+
+	/* Extra values when packing */
+	grib_values extra_settings[80]; 
+	long        extra_settings_count;
+} grib_util_packing_spec;
+
+
+grib_handle *grib_util_set_spec(grib_handle *h, 
+	const grib_util_grid_spec    *grid_spec, 
+	const grib_util_packing_spec *packing_spec,  /* NULL for defaults (same as input) */
+	int flags,
+	const double *data_values, 
+	size_t data_values_count, 
+	int *err);
+
+
+/* --------------------------------------- */
+
 
 #ifdef __cplusplus
 }
@@ -1236,9 +1427,13 @@ void *wmo_read_any_from_file_malloc(FILE *f, int *err);
 /* This part is automatically generated by ./errors.pl, do not edit */
 #ifndef grib_errors_H
 #define grib_errors_H
+/*! \defgroup errors Error codes
+Error codes returned by the grib_api functions.
+*/
+/*! @{*/
 /** No error */
 #define GRIB_SUCCESS		0
-/** End of ressource reached */
+/** End of resource reached */
 #define GRIB_END_OF_FILE		-1
 /** Internal error */
 #define GRIB_INTERNAL_ERROR		-2
@@ -1254,94 +1449,97 @@ void *wmo_read_any_from_file_malloc(FILE *f, int *err);
 #define GRIB_FILE_NOT_FOUND		-7
 /** Code not found in code table */
 #define GRIB_CODE_NOT_FOUND_IN_TABLE		-8
-/** Code cannot unpack because of string too small */
-#define GRIB_STRING_TOO_SMALL_FOR_CODE_NAME		-9
 /** Array size mismatch */
-#define GRIB_WRONG_ARRAY_SIZE		-10
+#define GRIB_WRONG_ARRAY_SIZE		-9
 /** Key/value not found */
-#define GRIB_NOT_FOUND		-11
+#define GRIB_NOT_FOUND		-10
 /** Input output problem */
-#define GRIB_IO_PROBLEM		-12
+#define GRIB_IO_PROBLEM		-11
 /** Message invalid */
-#define GRIB_INVALID_MESSAGE		-13
+#define GRIB_INVALID_MESSAGE		-12
 /** Decoding invalid */
-#define GRIB_DECODING_ERROR		-14
+#define GRIB_DECODING_ERROR		-13
 /** Encoding invalid */
-#define GRIB_ENCODING_ERROR		-15
+#define GRIB_ENCODING_ERROR		-14
 /** Code cannot unpack because of string too small */
-#define GRIB_NO_MORE_IN_SET		-16
+#define GRIB_NO_MORE_IN_SET		-15
 /** Problem with calculation of geographic attributes */
-#define GRIB_GEOCALCULUS_PROBLEM		-17
+#define GRIB_GEOCALCULUS_PROBLEM		-16
 /** Out of memory */
-#define GRIB_OUT_OF_MEMORY		-18
+#define GRIB_OUT_OF_MEMORY		-17
 /** Value is read only */
-#define GRIB_READ_ONLY		-19
+#define GRIB_READ_ONLY		-18
 /** Invalid argument */
-#define GRIB_INVALID_ARGUMENT		-20
+#define GRIB_INVALID_ARGUMENT		-19
 /** Null handle */
-#define GRIB_NULL_HANDLE		-21
+#define GRIB_NULL_HANDLE		-20
 /** Invalid section number */
-#define GRIB_INVALID_SECTION_NUMBER		-22
+#define GRIB_INVALID_SECTION_NUMBER		-21
 /** Value cannot be missing */
-#define GRIB_VALUE_CANNOT_BE_MISSING		-23
+#define GRIB_VALUE_CANNOT_BE_MISSING		-22
 /** Wrong message length */
-#define GRIB_WRONG_LENGTH		-24
+#define GRIB_WRONG_LENGTH		-23
 /** Invalid key type */
-#define GRIB_INVALID_TYPE		-25
+#define GRIB_INVALID_TYPE		-24
 /** Unable to set step */
-#define GRIB_WRONG_STEP		-26
+#define GRIB_WRONG_STEP		-25
 /** Wrong units for step (step must be integer) */
-#define GRIB_WRONG_STEP_UNIT		-27
+#define GRIB_WRONG_STEP_UNIT		-26
 /** Invalid file id */
-#define GRIB_INVALID_FILE		-28
+#define GRIB_INVALID_FILE		-27
 /** Invalid grib id */
-#define GRIB_INVALID_GRIB		-29
+#define GRIB_INVALID_GRIB		-28
 /** Invalid index id */
-#define GRIB_INVALID_INDEX		-30
+#define GRIB_INVALID_INDEX		-29
 /** Invalid iterator id */
-#define GRIB_INVALID_ITERATOR		-31
+#define GRIB_INVALID_ITERATOR		-30
 /** Invalid keys iterator id */
-#define GRIB_INVALID_KEYS_ITERATOR		-32
+#define GRIB_INVALID_KEYS_ITERATOR		-31
 /** Invalid nearest id */
-#define GRIB_INVALID_NEAREST		-33
+#define GRIB_INVALID_NEAREST		-32
 /** Invalid order by */
-#define GRIB_INVALID_ORDERBY		-34
+#define GRIB_INVALID_ORDERBY		-33
 /** Missing a key from the fieldset */
-#define GRIB_MISSING_KEY		-35
+#define GRIB_MISSING_KEY		-34
 /** The point is out of the grid area */
-#define GRIB_OUT_OF_AREA		-36
+#define GRIB_OUT_OF_AREA		-35
 /** Concept no match */
-#define GRIB_CONCEPT_NO_MATCH		-37
+#define GRIB_CONCEPT_NO_MATCH		-36
 /** Definitions files not found */
-#define GRIB_NO_DEFINITIONS		-38
+#define GRIB_NO_DEFINITIONS		-37
 /** Wrong type while packing */
-#define GRIB_WRONG_TYPE		-39
+#define GRIB_WRONG_TYPE		-38
 /** End of resource */
-#define GRIB_END		-40
+#define GRIB_END		-39
 /** Unable to code a field without values */
-#define GRIB_NO_VALUES		-41
+#define GRIB_NO_VALUES		-40
 /** Grid description is wrong or inconsistent */
-#define GRIB_WRONG_GRID		-42
+#define GRIB_WRONG_GRID		-41
 /** End of index reached */
-#define GRIB_END_OF_INDEX		-43
+#define GRIB_END_OF_INDEX		-42
 /** Null index */
-#define GRIB_NULL_INDEX		-44
-/** End of ressource reached when reading message */
-#define GRIB_PREMATURE_END_OF_FILE		-45
+#define GRIB_NULL_INDEX		-43
+/** End of resource reached when reading message */
+#define GRIB_PREMATURE_END_OF_FILE		-44
 /** An internal array is too small */
-#define GRIB_INTERNAL_ARRAY_TOO_SMALL		-46
+#define GRIB_INTERNAL_ARRAY_TOO_SMALL		-45
 /** Message is too large for the current architecture */
-#define GRIB_MESSAGE_TOO_LARGE		-47
+#define GRIB_MESSAGE_TOO_LARGE		-46
 /** Constant field */
-#define GRIB_CONSTANT_FIELD		-48
+#define GRIB_CONSTANT_FIELD		-47
 /** Switch unable to find a matching case */
-#define GRIB_SWITCH_NO_MATCH		-49
+#define GRIB_SWITCH_NO_MATCH		-48
 /** Underflow */
-#define GRIB_UNDERFLOW		-50
+#define GRIB_UNDERFLOW		-49
 /** Message malformed */
-#define GRIB_MESSAGE_MALFORMED		-51
+#define GRIB_MESSAGE_MALFORMED		-50
 /** Index is corrupted */
-#define GRIB_CORRUPTED_INDEX		-52
+#define GRIB_CORRUPTED_INDEX		-51
 /** Invalid number of bits per value */
-#define GRIB_INVALID_BPV		-53
+#define GRIB_INVALID_BPV		-52
+/** Edition of two messages is different */
+#define GRIB_DIFFERENT_EDITION		-53
+/** Value is different */
+#define GRIB_VALUE_DIFFERENT		-54
+/*! @}*/
 #endif
