@@ -142,6 +142,7 @@ typedef               struct     grib_codetable          grib_codetable;
 typedef               struct     grib_accessor           grib_accessor;
 typedef               struct     grib_iterator_class     grib_iterator_class;
 typedef               struct     grib_nearest_class      grib_nearest_class;
+typedef               struct     grib_box_class          grib_box_class;
 typedef               struct     grib_dumper             grib_dumper;
 typedef               struct     grib_dumper_class       grib_dumper_class;
 typedef               struct     grib_dependency         grib_dependency;
@@ -155,7 +156,12 @@ typedef int            (*nearest_find_proc)    (grib_nearest* nearest, grib_hand
                                                   unsigned long flags, double* outlats,
                                                   double* outlons,double *values,
                                                   double* distances, int* indexes,size_t *len);
-typedef int            (*nearest_destroy_proc)          (grib_nearest* nearest);
+typedef int            (*nearest_destroy_proc)   (grib_nearest* nearest);
+
+typedef void           (*box_init_class_proc)    (grib_box_class*);
+typedef int            (*box_destroy_proc)       (grib_box*);
+typedef int            (*box_init_proc)          (grib_box* ,grib_handle*,grib_arguments*);
+typedef grib_points*   (*box_get_points_proc)    (grib_box*, double, double, double,double, int*);
 
 typedef void           (*iterator_init_class_proc)       (grib_iterator_class*);
 typedef int            (*iterator_init_proc)             (grib_iterator* i,grib_handle*,grib_arguments*);
@@ -175,6 +181,7 @@ typedef  void   (*accessor_destroy_proc)                  (grib_context* ,   gri
 typedef  int     (*accessor_unpack_long_proc)             (grib_accessor*, long*,   size_t *len);
 typedef  int     (*accessor_unpack_double_proc)           (grib_accessor*, double*, size_t *len);
 typedef  int     (*accessor_unpack_double_element_proc)         (grib_accessor*, size_t, double*);
+typedef  int     (*accessor_unpack_double_subarray_proc)         (grib_accessor*, double*,size_t , size_t);
 typedef  int     (*accessor_unpack_string_proc)           (grib_accessor*, char*,   size_t *len);
 typedef  int     (*accessor_unpack_bytes_proc)            (grib_accessor*, unsigned char*, size_t *len);
 typedef  int     (*accessor_get_native_type_proc)         (grib_accessor*);
@@ -288,6 +295,7 @@ struct grib_action
     char                    *defaultkey; /** name of the key used as default if not found  */
 	grib_arguments*         default_value; /** default expression as in .def file */
 	char*					set;
+    /* If you had something, don't forget to update grib_action_compile */
 };
 
 typedef struct grib_accessor_list grib_accessor_list;
@@ -297,12 +305,23 @@ struct grib_accessor_list {
 	grib_accessor_list* next;
 };
 
+/* compile */
+
+typedef struct grib_compiler {
+    int   cnt;
+    int   max;
+    FILE *out;
+    const char *var;
+} grib_compiler;
+
+
 
 typedef  int  (*action_create_accessors_handle_proc)        (grib_section* p, grib_action* a, grib_loader* h);
 typedef  int  (*action_notify_change_proc)                   (grib_action* a, grib_accessor* observer,grib_accessor * observed);
 
 typedef  void  (*grib_dump_proc)                         (grib_action*, FILE*, int );
 typedef  void  (*grib_xref_proc)                         (grib_action*, FILE*,const char*);
+typedef  void  (*grib_compile_proc)                         (grib_action*, grib_compiler*);
 typedef  void  (*action_init_class_proc)            (grib_action_class* a);
 typedef  void  (*action_init_proc)                  (grib_action* a);
 typedef  void  (*action_destroy_proc)                  (grib_context* context,  grib_action* a);
@@ -337,6 +356,8 @@ struct grib_action_class
 
   action_reparse_proc              reparse;
   action_execute_proc              execute;
+
+    grib_compile_proc             compile;    /** < compile method of the action                               */
 };
 
 
@@ -415,6 +436,8 @@ struct grib_accessor
 #define GRIB_ACCESSOR_FLAG_TRANSIENT        (1<<13)
 #define GRIB_ACCESSOR_FLAG_STRING_TYPE      (1<<14)
 #define GRIB_ACCESSOR_FLAG_LONG_TYPE        (1<<15)
+#define GRIB_ACCESSOR_FLAG_LOWERCASE        (1<<16)
+/* when adding a flag, update grib_compile_flags*/
 
 /**
 *  a section accessor
@@ -467,6 +490,19 @@ struct grib_nearest_class{
 
 };
 
+struct grib_box_class{
+   grib_box_class**           super;
+   char* name;
+   size_t                     size;
+   int                        inited;
+   box_init_class_proc        init_class;
+   box_init_proc              init;
+   box_destroy_proc           destroy;
+   box_get_points_proc        get_points;
+
+};
+
+/* --------------- */
 /* --------------- */
 typedef void (*search_all_callback_proc)(grib_accessor*,void* data);
 /* --------------- */
@@ -532,6 +568,16 @@ struct grib_nearest{
 
 };
 
+struct grib_box {
+   grib_box_class*             cclass;
+   grib_context*               context;
+   grib_arguments              *args;      
+   grib_handle*                h;
+   unsigned long               flags;
+   grib_points*                points;
+};
+
+
 struct grib_dependency {
    grib_dependency* next;
    grib_accessor*   observed;
@@ -659,6 +705,7 @@ struct grib_accessor_class
     accessor_next_proc              next;
     accessor_compare_proc           compare;
     accessor_unpack_double_element_proc     unpack_double_element;
+    accessor_unpack_double_subarray_proc    unpack_double_subarray;
     accessor_clear_proc             clear;
 };
 
@@ -677,12 +724,6 @@ struct grib_multi_support {
     grib_multi_support*             next;
 };
 
-typedef struct grib_string grib_string;
-struct grib_string {
-  char* string;
-  grib_string* next;
-};
-
 /* Concepts */
 typedef struct grib_concept_condition grib_concept_condition;
 
@@ -713,6 +754,9 @@ struct grib_context
 {
     int                             inited;
     int                             debug;
+    int                             write_on_fail;
+    int                             no_abort;
+	int 							io_buffer_size;
     char*                           grib_definition_files_path;
     char*                           grib_templates_path;
     char*                           grib_concept_path;
@@ -745,7 +789,7 @@ struct grib_context
     char*                           outfilename;
     int                             multi_support_on;
     grib_multi_support*             multi_support;
-    grib_string*                    grib_definition_files_dir;
+    grib_string_list*               grib_definition_files_dir;
     int                             handle_file_count;
     int                             handle_total_count;
     off_t                           message_file_offset;
@@ -759,7 +803,7 @@ struct grib_context
     grib_concept_value*             concepts[MAX_NUM_CONCEPTS];
     grib_trie*                      def_files;
     
-    grib_string*                    blacklist;
+    grib_string_list*                blacklist;
     int                             ieee_packing;
 	grib_trie*                      classes;
 #if GRIB_PTHREADS
@@ -769,6 +813,8 @@ struct grib_context
 };
 
 /* file_pool */
+grib_string_list grib_file_not_found;
+
 typedef struct grib_file grib_file;
 typedef struct grib_file_pool grib_file_pool;
 
@@ -777,6 +823,7 @@ struct grib_file {
   char* name;
   FILE* handle;
   char* mode;
+  char* buffer;
   long refcount;
   grib_file* next;
   short id;
@@ -901,8 +948,8 @@ struct grib_index_key {
   char* name;
   int type;
   char value[STRING_VALUE_LEN];
-  grib_string* values;
-  grib_string* current;
+  grib_string_list* values;
+  grib_string_list* current;
   int values_count;
   int count;
   grib_index_key* next;
