@@ -10,6 +10,7 @@ int grib_action_execute(grib_action *a, grib_handle *h);
 void grib_dump_action_branch(FILE *out, grib_action *a, int decay);
 void grib_dump_action_tree(grib_context *ctx, FILE *out);
 void grib_xref_action_branch(FILE *out, grib_action *a, const char *path);
+void grib_compile(grib_action *a, grib_compiler *compiler);
 
 /* action_class_alias.c */
 grib_action *grib_action_create_alias(grib_context *context, const char *name, const char *arg1, const char *name_space, int flags);
@@ -52,6 +53,7 @@ grib_action *grib_action_create_assert(grib_context *context, grib_expression *e
 
 /* action_class_template.c */
 grib_action *grib_action_create_template(grib_context *context, int nofail, const char *name, const char *arg1);
+grib_action *get_empty_template(grib_context *c, int *err);
 
 /* action_class_trigger.c */
 grib_action *grib_action_create_trigger(grib_context *context, grib_arguments *args, grib_action *block);
@@ -60,7 +62,7 @@ grib_action *grib_action_create_trigger(grib_context *context, grib_arguments *a
 grib_action *grib_action_create_when(grib_context *context, grib_expression *expression, grib_action *block_true, grib_action *block_false);
 
 /* action_class_concept.c */
-grib_action *grib_action_create_concept(grib_context *context, const char *name, grib_concept_value *concept, const char *basename, const char *name_space, const char *defaultkey, const char *masterDir, const char *localDir, int flags, int nofail);
+grib_action *grib_action_create_concept(grib_context *context, const char *name, grib_concept_value *concept, const char *basename, const char *name_space, const char *defaultkey, const char *masterDir, const char *localDir, const char *ecmfDir, int flags, int nofail);
 const char *grib_concept_evaluate(grib_handle *h, grib_action *act);
 int grib_concept_apply(grib_handle *h, grib_action *act, const char *name);
 
@@ -99,13 +101,12 @@ int grib_pack_string(grib_accessor *a, const char *v, size_t *len);
 int grib_pack_long(grib_accessor *a, const long *v, size_t *len);
 int grib_pack_bytes(grib_accessor *a, const unsigned char *v, size_t *len);
 int grib_unpack_bytes(grib_accessor *a, unsigned char *v, size_t *len);
+int grib_unpack_double_subarray(grib_accessor *a, double *v, size_t start, size_t len);
 int grib_unpack_double(grib_accessor *a, double *v, size_t *len);
 int grib_unpack_double_element(grib_accessor *a, size_t i, double *v);
 int grib_unpack_string(grib_accessor *a, char *v, size_t *len);
 int grib_unpack_long(grib_accessor *a, long *v, size_t *len);
 long grib_accessor_get_native_type(grib_accessor *a);
-grib_section *grib_get_sub_section(grib_accessor *a);
-grib_section *grib_get_sub_section(grib_accessor *a);
 long grib_get_next_position_offset(grib_accessor *a);
 long grib_byte_offset(grib_accessor *a);
 long grib_byte_count(grib_accessor *a);
@@ -139,9 +140,6 @@ grib_iarray *grib_iarray_resize(grib_context *c, grib_iarray *v);
 grib_iarray *grib_iarray_push(grib_context *c, grib_iarray *v, long val);
 void grib_iarray_delete(grib_context *c, grib_iarray *v);
 
-/* grib_accessor_classes_hash.c */
-struct accessor_class_hash *grib_accessor_classes_hash(const char *str, unsigned int len);
-
 /* grib_accessor_class_array.c */
 
 /* grib_accessor_class_assert.c */
@@ -249,6 +247,8 @@ int grib_g1_step_apply_units(long *start, long *end, long *step_unit, long *P1,
 
 /* grib_accessor_class_g2latlon.c */
 
+/* grib_accessor_class_global_gaussian.c */
+
 /* grib_accessor_class_gen.c */
 
 /* grib_accessor_class_gts_header.c */
@@ -289,9 +289,10 @@ grib_iterator *grib_iterator_new(grib_handle *h, unsigned long flags, int *error
 /* grib_accessor_class_nearest.c */
 grib_nearest *grib_nearest_new(grib_handle *h, int *error);
 
-/* grib_accessor_class_ksec1expver.c */
+/* grib_accessor_class_box.c */
+grib_box *grib_box_new(grib_handle *h, int *error);
 
-/* grib_accessor_class_ksec.c */
+/* grib_accessor_class_ksec1expver.c */
 
 /* grib_accessor_class_label.c */
 
@@ -301,6 +302,8 @@ grib_nearest *grib_nearest_new(grib_handle *h, int *error);
 
 /* grib_accessor_class_octect_number.c */
 
+/* grib_accessor_class_headers_only.c */
+
 /* grib_accessor_class_padding.c */
 
 /* grib_accessor_class_pad.c */
@@ -518,23 +521,7 @@ int grib_encode_signed_long(unsigned char *p, long val, long o, int l);
 int grib_get_bit(const unsigned char *p, long bitp);
 void grib_set_bit(unsigned char *p, long bitp, int val);
 long grib_decode_signed_longb(const unsigned char *p, long *bitp, long nbits);
-unsigned long grib_decode_unsigned_long(const unsigned char *p, long *bitp, long nbits);
-int grib_decode_double_array(const unsigned char *p, long *bitp, long nbits, double reference_value, double s, double d, size_t size, double *val);
-int grib_decode_double_array_complex(const unsigned char *p, long *bitp, long nbits, double reference_value, double s, double *d, size_t size, double *val);
-int grib_decode_double_array(const unsigned char *p, long *bitp, long nbits, double reference_value, double s, double d, size_t size, double *val);
-int grib_decode_double_array_complex(const unsigned char *p, long *bitp, long nbits, double reference_value, double s, double *d, size_t size, double *val);
-unsigned long grib_decode_unsigned_long(const unsigned char *p, long *bitp, long nbits);
-int grib_decode_double_array(const unsigned char *p, long *bitp, long bitsPerValue, double reference_value, double s, double d, size_t n_vals, double *val);
-int grib_decode_double_array_complex(const unsigned char *p, long *bitp, long nbits, double reference_value, double s, double *d, size_t size, double *val);
 int grib_encode_signed_longb(unsigned char *p, long val, long *bitp, long nb);
-int grib_encode_unsigned_long(unsigned char *p, unsigned long val, long *bitp, long nbits);
-int grib_encode_unsigned_longb(unsigned char *p, unsigned long val, long *bitp, long nbits);
-int grib_encode_double_array(size_t n_vals, const double *val, long nbits, double reference_value, double d, double divisor, unsigned char *p, long *bitp);
-int grib_encode_double_array_complex(size_t n_vals, double *val, long nbits, double reference_value, double *scal, double d, double divisor, unsigned char *p, long *bitp);
-int grib_encode_unsigned_long(unsigned char *p, unsigned long val, long *bitp, long nbits);
-int grib_encode_unsigned_longb(unsigned char *p, unsigned long val, long *bitp, long nb);
-int grib_encode_double_array(size_t n_vals, const double *val, long bits_per_value, double reference_value, double d, double divisor, unsigned char *p, long *off);
-int grib_encode_double_array_complex(size_t n_vals, double *val, long nbits, double reference_value, double *scal, double d, double divisor, unsigned char *p, long *bitp);
 
 /* grib_timer.c */
 double proc_cpu(void);
@@ -654,7 +641,7 @@ long grib_get_api_version(void);
 void grib_print_api_version(FILE *out);
 grib_context *grib_context_get_default(void);
 grib_context *grib_context_new(grib_context *parent);
-const char *grib_context_full_path(grib_context *c, const char *basename, char *full);
+char *grib_context_full_path(grib_context *c, const char *basename);
 void grib_context_free(const grib_context *c, void *p);
 void grib_context_free_persistent(const grib_context *c, void *p);
 void grib_context_reset(grib_context *c);
@@ -721,6 +708,7 @@ int grib_handle_delete(grib_handle *h);
 grib_handle *grib_new_handle(grib_context *c);
 grib_handle *grib_handle_new_from_template(grib_context *c, const char *name);
 grib_handle *grib_handle_new_from_samples(grib_context *c, const char *name);
+int grib_write_message(grib_handle *h, const char *file, const char *mode);
 grib_handle *grib_handle_clone(grib_handle *h);
 grib_handle *grib_handle_new_from_message_copy(grib_context *c, const void *data, size_t size);
 grib_handle *grib_handle_new_from_partial_message_copy(grib_context *c, const void *data, size_t size);
@@ -728,6 +716,8 @@ grib_handle *grib_handle_new_from_partial_message(grib_context *c, void *data, s
 grib_handle *grib_handle_new_from_message(grib_context *c, void *data, size_t buflen);
 grib_handle *grib_handle_new_from_multi_message(grib_context *c, void **data, size_t *buflen, int *error);
 grib_handle *grib_handle_new_from_file(grib_context *c, FILE *f, int *error);
+grib_handle *grib_handle_new_from_nc_file(grib_context *c, const char *file, int *error);
+grib_handle *grib_handle_headers_only_new_from_file(grib_context *c, FILE *f, int *error);
 grib_multi_handle *grib_multi_handle_new(grib_context *c);
 int grib_multi_handle_delete(grib_multi_handle *h);
 int grib_multi_handle_append(grib_handle *h, int start_section, grib_multi_handle *mh);
@@ -745,6 +735,7 @@ void grib_multi_support_on(grib_context *c);
 void grib_multi_support_off(grib_context *c);
 void grib_gts_header_on(grib_context *c);
 void grib_gts_header_off(grib_context *c);
+int grib_get_gribex_mode(grib_context *c);
 void grib_gribex_mode_on(grib_context *c);
 void grib_gribex_mode_off(grib_context *c);
 void grib_multi_support_reset(grib_context *c);
@@ -764,6 +755,9 @@ int grib_hash_keys_insert(grib_itrie *t, const char *key);
 int grib_hash_keys_get_size(grib_itrie *t);
 
 /* grib_io.c */
+off_t stdio_tell(void *data);
+int stdio_seek(void *data, off_t len);
+int stdio_read(void *data, void *buf, int len, int *err);
 int wmo_read_any_from_file(FILE *f, void *buffer, size_t *len);
 int wmo_read_grib_from_file(FILE *f, void *buffer, size_t *len);
 int wmo_read_bufr_from_file(FILE *f, void *buffer, size_t *len);
@@ -771,7 +765,9 @@ int wmo_read_any_from_stream(void *stream_data, long (*stream_proc )(void *, voi
 void *wmo_read_any_from_file_malloc(FILE *f, int *err);
 void *wmo_read_grib_from_file_malloc(FILE *f, int *err);
 void *wmo_read_bufr_from_file_malloc(FILE *f, int *err);
+int grib_read_any_headers_only_from_file_alloc(grib_context *ctx, FILE *f, void **buffer, size_t *length, off_t *offset);
 int grib_read_any_from_file_alloc(grib_context *ctx, FILE *f, void **buffer, size_t *length);
+int grib_read_any_headers_only_from_file(grib_context *ctx, FILE *f, void *buffer, size_t *len);
 int grib_read_any_from_file(grib_context *ctx, FILE *f, void *buffer, size_t *len);
 int grib_read_any_from_memory_alloc(grib_context *ctx, unsigned char **data, size_t *data_length, void **buffer, size_t *length);
 int grib_read_any_from_memory(grib_context *ctx, unsigned char **data, size_t *data_length, void *buffer, size_t *len);
@@ -875,6 +871,7 @@ int grib_get_double_internal(grib_handle *h, const char *name, double *val);
 int grib_get_double(grib_handle *h, const char *name, double *val);
 int grib_get_double_element_internal(grib_handle *h, const char *name, int i, double *val);
 int grib_get_double_element(grib_handle *h, const char *name, int i, double *val);
+int grib_points_get_values(grib_handle *h, grib_points *points, double *val);
 int grib_get_double_elements(grib_handle *h, const char *name, int *i, long len, double *val);
 int grib_get_string_internal(grib_handle *h, const char *name, char *val, size_t *length);
 int grib_get_string(grib_handle *h, const char *name, char *val, size_t *length);
@@ -899,6 +896,7 @@ int grib_get_values(grib_handle *h, grib_values *args, size_t count);
 int grib_set_values(grib_handle *h, grib_values *args, size_t count);
 int grib_get_nearest_smaller_value(grib_handle *h, const char *name, double val, double *nearest);
 void grib_print_values(grib_values *values, int count);
+int grib_values_check(grib_handle *h, grib_values *values, int count);
 
 /* grib_errors.c */
 const char *grib_get_error_message(int code);
@@ -932,6 +930,22 @@ grib_expression *new_double_expression(grib_context *c, double value);
 /* grib_expression_class_string.c */
 grib_expression *new_string_expression(grib_context *c, const char *value);
 
+/* grib_box.c */
+grib_points *grib_box_get_points(grib_box *box, double north, double west, double south, double east, int *err);
+int grib_box_init(grib_box *box, grib_handle *h, grib_arguments *args);
+int grib_box_delete(grib_box *box);
+grib_points *grib_points_new(grib_context *c, size_t size);
+void grib_points_delete(grib_points *points);
+
+/* grib_box_class.c */
+grib_box *grib_box_factory(grib_handle *h, grib_arguments *args);
+
+/* grib_box_class_gen.c */
+
+/* grib_box_class_regular_gaussian.c */
+
+/* grib_box_class_reduced_gaussian.c */
+
 /* grib_nearest.c */
 int grib_nearest_find(grib_nearest *nearest, grib_handle *h, double inlat, double inlon, unsigned long flags, double *outlats, double *outlons, double *values, double *distances, int *indexes, size_t *len);
 int grib_nearest_init(grib_nearest *i, grib_handle *h, grib_arguments *args);
@@ -986,10 +1000,11 @@ int grib_expression_evaluate_double(grib_handle *h, grib_expression *g, double *
 const char *grib_expression_evaluate_string(grib_handle *h, grib_expression *g, char *buf, size_t *size, int *err);
 const char *grib_expression_get_name(grib_expression *g);
 void grib_expression_print(grib_context *ctx, grib_expression *g, grib_handle *f);
+void grib_expression_compile(grib_expression *g, grib_compiler *f);
 void grib_expression_free(grib_context *ctx, grib_expression *g);
 void grib_expression_add_dependency(grib_expression *e, grib_accessor *observer);
 int grib_expression_set_value(grib_handle *h, grib_expression *g, grib_values *v);
-grib_arguments *grib_arguments_new(grib_context *c, grib_expression *g);
+grib_arguments *grib_arguments_new(grib_context *c, grib_expression *g, grib_arguments *n);
 void grib_arguments_free(grib_context *c, grib_arguments *g);
 void grib_arguments_print(grib_context *c, grib_arguments *g, grib_handle *f);
 const char *grib_arguments_get_name(grib_handle *h, grib_arguments *args, int n);
@@ -998,9 +1013,67 @@ long grib_arguments_get_long(grib_handle *h, grib_arguments *args, int n);
 double grib_arguments_get_double(grib_handle *h, grib_arguments *args, int n);
 grib_expression *grib_arguments_get_expression(grib_handle *h, grib_arguments *args, int n);
 
+/* grib_util.c */
+grib_handle *grib_util_sections_copy(grib_handle *hfrom, grib_handle *hto, int what, int *err);
+grib_string_list *grib_util_get_param_id(const char *mars_param);
+grib_string_list *grib_util_get_mars_param(const char *param_id);
+grib_handle *grib_util_set_spec(grib_handle *h, const grib_util_grid_spec *spec, const grib_util_packing_spec *packing_spec, int flags, const double *data_values, size_t data_values_count, int *err);
+
+/* compile.c */
+void grib_compile_flags(grib_compiler *c, long flags);
+void grib_compile_action_branch(grib_action *a, grib_compiler *c, char *name);
+void grib_compile_expression(grib_expression *e, grib_compiler *compiler);
+void grib_compile_arguments(grib_arguments *a, grib_compiler *compiler);
+
+/* functions.c */
+long grib_op_eq(long a, long b);
+long grib_op_ne(long a, long b);
+long grib_op_lt(long a, long b);
+long grib_op_gt(long a, long b);
+long grib_op_and(long a, long b);
+long grib_op_or(long a, long b);
+long grib_op_ge(long a, long b);
+long grib_op_le(long a, long b);
+long grib_op_bit(long a, long b);
+long grib_op_bitoff(long a, long b);
+long grib_op_not(long a);
+long grib_op_neg(long a);
+double grib_op_neg_d(double a);
+long grib_op_pow(long a, long b);
+long grib_op_add(long a, long b);
+long grib_op_sub(long a, long b);
+long grib_op_div(long a, long b);
+long grib_op_mul(long a, long b);
+long grib_op_modulo(long a, long b);
+double grib_op_mul_d(double a, double b);
+double grib_op_div_d(double a, double b);
+double grib_op_add_d(double a, double b);
+double grib_op_sub_d(double a, double b);
+double grib_op_eq_d(double a, double b);
+double grib_op_ne_d(double a, double b);
+double grib_op_lt_d(double a, double b);
+double grib_op_gt_d(double a, double b);
+double grib_op_ge_d(double a, double b);
+double grib_op_le_d(double a, double b);
+const char *grib_binop_long_proc_name(grib_binop_long_proc proc);
+const char *grib_binop_double_proc_name(grib_binop_double_proc proc);
+const char *grib_unop_long_proc_name(grib_unop_long_proc proc);
+const char *grib_unop_double_proc_name(grib_unop_double_proc proc);
+
 /* md5.c */
 void cvs_MD5Init(struct cvs_MD5Context *ctx);
 void cvs_MD5Update(struct cvs_MD5Context *ctx, unsigned char const *buf, unsigned len);
 void cvs_MD5Final(unsigned char digest[16 ], struct cvs_MD5Context *ctx);
 void cvs_MD5Transform(cvs_uint32 buf[4 ], const unsigned char inraw[64 ]);
 int main(int argc, char **argv);
+
+/* grib_bits_any_endian.c */
+unsigned long grib_decode_unsigned_long(const unsigned char *p, long *bitp, long nbits);
+int grib_encode_unsigned_long(unsigned char *p, unsigned long val, long *bitp, long nbits);
+int grib_encode_unsigned_longb(unsigned char *p, unsigned long val, long *bitp, long nb);
+
+/* grib_bits_any_endian_simple.c */
+int grib_decode_double_array(const unsigned char *p, long *bitp, long bitsPerValue, double reference_value, double s, double d, size_t n_vals, double *val);
+int grib_decode_double_array_complex(const unsigned char *p, long *bitp, long nbits, double reference_value, double s, double *d, size_t size, double *val);
+int grib_encode_double_array(size_t n_vals, const double *val, long bits_per_value, double reference_value, double d, double divisor, unsigned char *p, long *off);
+int grib_encode_double_array_complex(size_t n_vals, double *val, long nbits, double reference_value, double *scal, double d, double divisor, unsigned char *p, long *bitp);
