@@ -12,9 +12,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-static int file_found=1;
-static int file_not_found=2;
-
 #if MANAGE_MEM
 
 #else
@@ -83,11 +80,11 @@ static void  default_log(const grib_context* c, int level, const char* mess){
 		/*Assert(1==0);*/
 	}
 	if(level == GRIB_LOG_FATAL)   fprintf(stderr, "GRIB_API ERROR   :  %s\n", mess);
-	if(level == GRIB_LOG_DEBUG)   fprintf(stderr, "GRIB_API DEBUG   :  %s\n", mess);
+	if(level == GRIB_LOG_DEBUG && c->debug>0)   fprintf(stderr, "GRIB_API DEBUG   :  %s\n", mess);
 	if(level == GRIB_LOG_WARNING) fprintf(stderr, "GRIB_API WARNING :  %s\n", mess);
 	if(level == GRIB_LOG_INFO)    fprintf(stderr, "GRIB_API INFO    :  %s\n", mess);
 
-	if(level == GRIB_LOG_FATAL) { abort(); }
+	if(level == GRIB_LOG_FATAL) { Assert(0);}
 
 	if(getenv("GRIB_API_FAIL_IF_LOG_MESSAGE"))
 	{
@@ -136,6 +133,9 @@ void grib_print_api_version(FILE* out) {
 static  grib_context default_grib_context = {
 	0,                            /* inited                     */
 	0,                            /* debug                      */
+	0,                            /* write_on_fail              */
+	0,                            /* no_abort                   */
+	0,                            /* io_buffer_size             */
 	0,                            /* grib_definition_files_path */
 	0,                            /* grib_templates_path        */
 	0,                            /* grib_concept_path          */
@@ -220,10 +220,16 @@ grib_context* grib_context_get_default(){
 
 	if(!default_grib_context.inited)
 	{
+		const char * write_on_fail = getenv("GRIB_API_WRITE_ON_FAIL");
+		const char * no_abort = getenv("GRIB_API_NO_ABORT");
 		const char * debug = getenv("GRIB_API_DEBUG");
 		const char *gribex=getenv("GRIB_GRIBEX_MODE_ON");
 		const char *ieee_packing=getenv("GRIB_IEEE_PACKING");
+		const char *io_buffer_size=getenv("GRIB_API_IO_BUFFER_SIZE");
 		default_grib_context.inited = 1;
+		default_grib_context.io_buffer_size = io_buffer_size ? atoi(io_buffer_size) : 0;
+		default_grib_context.write_on_fail  = write_on_fail ? atoi(write_on_fail) : 0;
+		default_grib_context.no_abort  = no_abort ? atoi(no_abort) : 0;
 		default_grib_context.debug  = debug ? atoi(debug) : 0;
 		default_grib_context.gribex_mode_on=gribex ? atoi(gribex) : 0;
 		default_grib_context.ieee_packing=ieee_packing ? atoi(ieee_packing) : 0;
@@ -305,9 +311,10 @@ static int init_definition_files_dir(grib_context* c) {
 	char* path=NULL;
 	char* p=NULL;
 	char* dir=NULL;
-	grib_string* next=NULL;
+	grib_string_list* next=NULL;
 
 	if (!c) c=grib_context_get_default();
+
 	if (c->grib_definition_files_dir) return 0;
 	if (!c->grib_definition_files_path) return GRIB_NO_DEFINITIONS;
 
@@ -319,20 +326,20 @@ static int init_definition_files_dir(grib_context* c) {
 	while(*p!=':' && *p!='\0') p++;
 
 	if (*p != ':') {
-		c->grib_definition_files_dir=(grib_string*)grib_context_malloc_clear_persistent(c,sizeof(grib_string));
-		c->grib_definition_files_dir->string=grib_context_strdup(c,path);
+		c->grib_definition_files_dir=(grib_string_list*)grib_context_malloc_clear_persistent(c,sizeof(grib_string_list));
+		c->grib_definition_files_dir->value=grib_context_strdup(c,path);
 	} else {
 		dir=strtok(path,":");
 
 		while (dir != NULL) {
 			if (next) {
-				next->next=(grib_string*)grib_context_malloc_clear_persistent(c,sizeof(grib_string));
+				next->next=(grib_string_list*)grib_context_malloc_clear_persistent(c,sizeof(grib_string_list));
 				next=next->next;
 			} else {
-				c->grib_definition_files_dir=(grib_string*)grib_context_malloc_clear_persistent(c,sizeof(grib_string));
+				c->grib_definition_files_dir=(grib_string_list*)grib_context_malloc_clear_persistent(c,sizeof(grib_string_list));
 				next=c->grib_definition_files_dir;
 			}
-			next->string=grib_context_strdup(c,dir);
+			next->value=grib_context_strdup(c,dir);
 			dir=strtok(NULL,":");
 		}
 	}
@@ -342,20 +349,22 @@ static int init_definition_files_dir(grib_context* c) {
 	return err;
 }
 
-const char *grib_context_full_path(grib_context* c,
-		const char* basename, char *full)
+char *grib_context_full_path(grib_context* c,const char* basename)
 {
 	int err=0;
-	grib_string* dir=NULL;
+	char full[1024]={0,};
+	grib_string_list* dir=NULL;
+	grib_string_list* fullpath=0;
 	if (!c) c=grib_context_get_default();
 
 	GRIB_MUTEX_LOCK(&(c->mutex));
 
-	full[0]='\0';
 	if(*basename == '/' || *basename ==  '.') {
-		strcpy(full,basename);
-		return full;
+		return (char*)basename;
 	} else {
+		if ((fullpath=grib_trie_get(c->def_files,basename))!=NULL) {
+			return fullpath->value;
+		}
 		if (!c->grib_definition_files_dir)
 			err=init_definition_files_dir(c);
 
@@ -365,36 +374,32 @@ const char *grib_context_full_path(grib_context* c,
 			return NULL;
 		}
 
-		if (c->grib_definition_files_dir) {
-			dir=c->grib_definition_files_dir;
+		dir=c->grib_definition_files_dir;
 
-			while (dir) {
-				int *found=NULL;
-				sprintf(full,"%s/%s",dir->string,basename);
-				if ((found=grib_trie_get(c->def_files,full))!=NULL) 
-					return *found != file_found ? NULL : full;
-				if (!access(full,F_OK)) {
-					grib_trie_insert(c->def_files,full,&file_found);
-					grib_context_log(c,GRIB_LOG_DEBUG,"Found def file %s",full);
-					GRIB_MUTEX_UNLOCK(&(c->mutex));
-					return full;
-				}
-				dir=dir->next;
+		while (dir) {
+			sprintf(full,"%s/%s",dir->value,basename);
+			if (!access(full,F_OK)) {
+				fullpath=grib_context_malloc_clear_persistent(c,sizeof(grib_string_list));
+				Assert(fullpath);
+				fullpath->value=grib_context_strdup(c,full);
+				grib_trie_insert(c->def_files,basename,fullpath);
+				grib_context_log(c,GRIB_LOG_DEBUG,"Found def file %s",full);
+				GRIB_MUTEX_UNLOCK(&(c->mutex));
+				return fullpath->value;
 			}
-
+			dir=dir->next;
 		}
 
 	}
 
 	/* Store missing files so we don't check for them again and again */
-	grib_trie_insert(c->def_files,full,&file_not_found);
+	grib_trie_insert(c->def_files,basename,&grib_file_not_found);
 	/*grib_context_log(c,GRIB_LOG_ERROR,"Def file \"%s\" not found",basename);*/
 	GRIB_MUTEX_UNLOCK(&(c->mutex));
 	full[0]=0;
 	return NULL;
 }
 
-
 void grib_context_free(const grib_context* c, void* p){
 	if (!c) c=grib_context_get_default();
 	if(p)  c->free_mem(c,p);
@@ -459,7 +464,7 @@ void grib_context_delete( grib_context* c){
 void* grib_context_malloc_persistent(const grib_context* c, size_t size){
 	void* p =  c->alloc_persistent_mem(c,size);
 	if(!p) {
-		grib_context_log(c,GRIB_LOG_ERROR,"grib_context_malloc: error allocating %d bytes",size);
+		grib_context_log(c,GRIB_LOG_FATAL,"grib_context_malloc: error allocating %lu bytes",(unsigned long)size);
 		Assert(1);
 	}
 	return p;
@@ -484,7 +489,7 @@ void* grib_context_malloc(const grib_context* c, size_t size){
 	if(size == 0) return p;
 	else p=c->alloc_mem(c,size);
 	if(!p) {
-		grib_context_log(c,GRIB_LOG_ERROR,"grib_context_malloc: error allocating %d bytes",size);
+		grib_context_log(c,GRIB_LOG_FATAL,"grib_context_malloc: error allocating %lu bytes",(unsigned long)size);
 		Assert(1);
 	}
 	return p;
@@ -497,7 +502,7 @@ void* grib_context_realloc(const grib_context* c, void *p,size_t size){
 	q=c->realloc_mem(c,p,size);
 
 	if(!q) {
-		grib_context_log(c,GRIB_LOG_ERROR,"grib_context_realloc: error allocating %d bytes",size);
+		grib_context_log(c,GRIB_LOG_FATAL,"grib_context_realloc: error allocating %lu bytes",(unsigned long)size);
 		exit(1);
 	}
 	return q;
@@ -521,7 +526,7 @@ void* grib_context_buffer_malloc(const grib_context* c, size_t size){
 	if(size == 0) return p;
 	else p=c->alloc_buffer_mem(c,size);
 	if(!p) {
-		grib_context_log(c,GRIB_LOG_ERROR,"grib_context_buffer_malloc: error allocating %d bytes",size);
+		grib_context_log(c,GRIB_LOG_FATAL,"grib_context_buffer_malloc: error allocating %lu bytes",(unsigned long)size);
 		exit(1);
 	}
 	return p;
@@ -537,7 +542,7 @@ void* grib_context_buffer_realloc(const grib_context* c, void *p,size_t size){
 	void* q=c->realloc_buffer_mem(c,p,size);
 
 	if(!q) {
-		grib_context_log(c,GRIB_LOG_ERROR,"grib_context_buffer_realloc: error allocating %d bytes",size);
+		grib_context_log(c,GRIB_LOG_FATAL,"grib_context_buffer_realloc: error allocating %lu bytes",(unsigned long)size);
 		exit(1);
 	}
 	return q;
@@ -585,7 +590,7 @@ void grib_context_log(const grib_context *c,int level, const char* fmt, ...)
 	va_list list;
 
 	/* Save some CPU */
-	if( level == GRIB_LOG_DEBUG && !c->debug )
+	if( level == GRIB_LOG_DEBUG && c->debug<1 )
 		return;
 
 	va_start(list,fmt);
