@@ -180,7 +180,7 @@ int grib_index_compress(grib_index* index) {
 static grib_index_key* grib_index_new_key(grib_context* c,grib_index_key* keys,
 		const char* key,int type,int *err) {
 	grib_index_key *next=NULL,*current=NULL;
-	grib_string* values=NULL;
+	grib_string_list* values=NULL;
 
 	next=(grib_index_key*)grib_context_malloc_clear(c,sizeof(grib_index_key));
 	if (!next) {
@@ -190,11 +190,11 @@ static grib_index_key* grib_index_new_key(grib_context* c,grib_index_key* keys,
 		*err=GRIB_OUT_OF_MEMORY;
 		return NULL;
 	}
-	values=grib_context_malloc_clear(c,sizeof(grib_string));
+	values=grib_context_malloc_clear(c,sizeof(grib_string_list));
 	if (!values) {
 		grib_context_log(c,GRIB_LOG_ERROR,
 				"unable to allocate %d bytes",
-				sizeof(grib_string));
+				sizeof(grib_string_list));
 		*err=GRIB_OUT_OF_MEMORY;
 		return NULL;
 	}
@@ -455,12 +455,12 @@ grib_index* grib_index_new(grib_context* c,const char* key,int *err) {
 	return index;
 }
 
-static void grib_index_values_delete(grib_context* c,grib_string* values) {
+static void grib_index_values_delete(grib_context* c,grib_string_list* values) {
 
 	if (!values) return;
 
 	grib_index_values_delete(c,values->next);
-	grib_context_free(c,values->string);
+	grib_context_free(c,values->value);
 	grib_context_free(c,values);
 
 	return ;
@@ -481,8 +481,8 @@ static void grib_index_key_delete(grib_context* c,grib_index_key* keys) {
 
 
 static long values_count=0;
-static grib_string* grib_read_key_values(grib_context* c,FILE* fh,int *err) {
-	grib_string* values;
+static grib_string_list* grib_read_key_values(grib_context* c,FILE* fh,int *err) {
+	grib_string_list* values;
 	unsigned char marker=0;
 
 	*err = grib_read_uchar(fh,&marker);
@@ -491,8 +491,8 @@ static grib_string* grib_read_key_values(grib_context* c,FILE* fh,int *err) {
 
 	values_count++;
 
-	values=grib_context_malloc_clear(c,sizeof(grib_string));
-	values->string=grib_read_string(c,fh,err);
+	values=grib_context_malloc_clear(c,sizeof(grib_string_list));
+	values->value=grib_read_string(c,fh,err);
 	if (*err) return NULL;
 
 	values->next=grib_read_key_values(c,fh,err);
@@ -502,7 +502,7 @@ static grib_string* grib_read_key_values(grib_context* c,FILE* fh,int *err) {
 }
 
 
-static int grib_write_key_values(FILE* fh,grib_string* values) {
+static int grib_write_key_values(FILE* fh,grib_string_list* values) {
 	int err=0;
 
 	if (!values) 
@@ -511,7 +511,7 @@ static int grib_write_key_values(FILE* fh,grib_string* values) {
 	err=grib_write_not_null_marker(fh);
 	if (err) return err;
 
-	err=grib_write_string(fh,values->string);
+	err=grib_write_string(fh,values->value);
 
 	err=grib_write_key_values(fh,values->next);
 	if (err) return err;
@@ -598,6 +598,7 @@ static void grib_field_tree_delete(grib_context* c,grib_field_tree* tree) {
 	if(!tree)  return;
 
 	grib_field_delete(c,tree->field);
+	grib_context_free(c,tree->value);
 	
 	grib_field_tree_delete(c,tree->next_level);
 
@@ -609,8 +610,14 @@ static void grib_field_tree_delete(grib_context* c,grib_field_tree* tree) {
 }
 
 void grib_index_delete(grib_index* index) {
+	grib_file* file=index->files;
 	grib_index_key_delete(index->context,index->keys);
 	grib_field_tree_delete(index->context,index->fields); 
+	while (file) {
+		grib_file* f=file;
+		file=file->next;
+		grib_file_delete(f);
+	}
 	grib_context_free(index->context,index);
 }
 
@@ -719,6 +726,8 @@ grib_index* grib_index_read(grib_context* c,const char* filename,int *err) {
 	int max=0;
 	FILE* fh;
 
+  if (!c) c=grib_context_get_default();
+
 	fh=fopen(filename,"r");
 	if (!fh) {
 		grib_context* c = grib_context_get_default();
@@ -877,7 +886,7 @@ int grib_index_add_file(grib_index* index,const char* filename) {
 	fseeko(file->handle,0,SEEK_SET);
 
 	while ((h=grib_handle_new_from_file(c,file->handle,&err))!=NULL) {
-		grib_string* v=0;
+		grib_string_list* v=0;
 		index_key=index->keys;
 		field_tree=index->fields;
 		index_key->value[0]=0;
@@ -920,17 +929,17 @@ int grib_index_add_file(grib_index* index,const char* filename) {
 				return err;
 			}
 
-			if (!index_key->values->string) {
-				index_key->values->string=grib_context_strdup(c,buf);
+			if (!index_key->values->value) {
+				index_key->values->value=grib_context_strdup(c,buf);
 				index_key->values_count++;
 			} else {
 				v=index_key->values;
-				while (v->next && strcmp(v->string,buf)) v=v->next;
-				if (strcmp(v->string,buf)) {
+				while (v->next && strcmp(v->value,buf)) v=v->next;
+				if (strcmp(v->value,buf)) {
 					index_key->values_count++;
 					if (v->next) v=v->next;
-					v->next=grib_context_malloc_clear(c,sizeof(grib_string));
-					v->next->string=grib_context_strdup(c,buf);
+					v->next=grib_context_malloc_clear(c,sizeof(grib_string_list));
+					v->next->value=grib_context_strdup(c,buf);
 				}
 			}
 
@@ -1017,14 +1026,14 @@ int grib_index_get_size(grib_index* index,const char* key,size_t* size) {
 int grib_index_get_string(grib_index* index,const char* key,
 		char** values,size_t *size) {
 	grib_index_key* k=index->keys;
-	grib_string* kv;
+	grib_string_list* kv;
 	int i=0;
 	while (k && strcmp(k->name,key)) k=k->next;
 	if (!k) return GRIB_NOT_FOUND;
 	if (k->values_count>*size) return GRIB_ARRAY_TOO_SMALL;
 	kv=k->values;
 	while (kv) {
-		values[i++]=grib_context_strdup(index->context,kv->string);
+		values[i++]=grib_context_strdup(index->context,kv->value);
 		kv=kv->next;
 	}
 	*size=k->values_count;
@@ -1036,7 +1045,7 @@ int grib_index_get_string(grib_index* index,const char* key,
 int grib_index_get_long(grib_index* index,const char* key,
 		long* values,size_t *size) {
 	grib_index_key* k=index->keys;
-	grib_string* kv;
+	grib_string_list* kv;
 	int i=0;
 	while (k && strcmp(k->name,key)) k=k->next;
 	if (!k) return GRIB_NOT_FOUND;
@@ -1048,8 +1057,8 @@ int grib_index_get_long(grib_index* index,const char* key,
 	if (k->values_count > *size) return GRIB_ARRAY_TOO_SMALL;
 	kv=k->values;
 	while (kv) {
-		if (strcmp(kv->string,GRIB_KEY_UNDEF) )
-                  values[i++]=atol(kv->string);
+		if (strcmp(kv->value,GRIB_KEY_UNDEF) )
+                  values[i++]=atol(kv->value);
         else
           values[i++]=UNDEF_LONG;
 		kv=kv->next;
@@ -1063,7 +1072,7 @@ int grib_index_get_long(grib_index* index,const char* key,
 int grib_index_get_double(grib_index* index,const char* key,
 		double* values,size_t *size) {
 	grib_index_key* k=index->keys;
-	grib_string* kv;
+	grib_string_list* kv;
 	int i=0;
 	while (k && strcmp(k->name,key)) k=k->next;
 	if (!k) return GRIB_NOT_FOUND;
@@ -1075,8 +1084,8 @@ int grib_index_get_double(grib_index* index,const char* key,
 	if (k->values_count>*size) return GRIB_ARRAY_TOO_SMALL;
 	kv=k->values;
 	while (kv) {
-      if (strcmp(kv->string,GRIB_KEY_UNDEF) )
-		values[i++]=atof(kv->string);
+      if (strcmp(kv->value,GRIB_KEY_UNDEF) )
+		values[i++]=atof(kv->value);
       else
         values[i++]=UNDEF_DOUBLE;
       
