@@ -77,8 +77,10 @@ int grib_set_long(grib_handle* h, const char* name, long val) {
 
   a = grib_find_accessor(h, name);
 
-  if(a){
+  if (h->context->debug==-1) 
+	  printf("GRIB_API DEBUG: grib_set_long %s=%ld\n",name,(long)val);
 
+  if(a){
     if(a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY)
       return GRIB_READ_ONLY;
 
@@ -141,8 +143,8 @@ int grib_copy_namespace(grib_handle* dest, const char* name, grib_handle* src) {
 	iter=grib_keys_iterator_new(src,0,(char*)name);
 	
 	if (!iter) {
-		printf("ERROR: unable to get iterator for %s\n",name );
-		exit(1);
+		grib_context_log(src->context,GRIB_LOG_ERROR,"grib_copy_namespace: unable to get iterator for %s",name );
+		return GRIB_INTERNAL_ERROR;
 	}
   
 	while(grib_keys_iterator_next(iter))  {
@@ -286,6 +288,9 @@ int grib_set_double(grib_handle* h, const char* name, double val) {
 
   a = grib_find_accessor(h, name);
 
+  if (h->context->debug==-1) 
+	  printf("GRIB_API DEBUG: grib_set_double %s=%g\n",name,val);
+
   if(a){
 
     if(a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY)
@@ -329,6 +334,9 @@ int grib_set_string(grib_handle* h, const char* name, const char* val, size_t *l
   int ret=0;
   grib_accessor* a = grib_find_accessor(h, name);
 
+  if (h->context->debug==-1) 
+	  printf("GRIB_API DEBUG: grib_set_string %s=%s\n",name,val);
+
   if(a)
   {
     if(a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY)
@@ -373,8 +381,8 @@ int grib_set_bytes(grib_handle* h, const char* name, const unsigned char* val, s
 
   if(a)
   {
-    if(a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY)
-      return GRIB_READ_ONLY;
+    /* if(a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) */
+      /* return GRIB_READ_ONLY; */
 
     ret=grib_pack_bytes(a, val, length);
     if(ret == GRIB_SUCCESS){
@@ -495,6 +503,9 @@ static int _grib_set_double_array_internal(grib_handle* h,grib_accessor* a,
       if(len) {
         err  = grib_pack_double(a, val + *encoded_length, &len);
         *encoded_length += len;
+		if(err == GRIB_SUCCESS){
+		      return grib_dependency_notify_change(a);
+	    }
       }
       else {
         grib_get_size(h,a->name,encoded_length);
@@ -622,6 +633,7 @@ int grib_get_long(grib_handle* h, const char* name, long* val)
   act = grib_find_accessor(h, name);
 
   ret = act ? grib_unpack_long(act, val, &l) : GRIB_NOT_FOUND;
+
   return ret;
 }
 
@@ -644,6 +656,7 @@ int grib_get_double(grib_handle* h, const char* name, double* val)
 
   if(act)
     return grib_unpack_double(act, val, &l);
+
   return GRIB_NOT_FOUND;
 }
 
@@ -669,6 +682,21 @@ int grib_get_double_element(grib_handle* h, const char* name, int i, double* val
   return GRIB_NOT_FOUND;
 }
 
+int grib_points_get_values(grib_handle* h, grib_points* points, double* val)
+{
+	int i,ret;
+	grib_accessor* a=NULL;
+
+	a=grib_find_accessor(h,"values");
+
+	for (i=0;i<points->n_groups;i++) {
+		ret=grib_unpack_double_subarray(a,val,points->group_start[i],points->group_len[i]);
+		if (ret) return ret;
+		val+=points->group_len[i];
+	}
+	return 0;
+}
+
 int grib_get_double_elements(grib_handle* h, const char* name, int* i, long len,double* val)
 {
   double* values=0;
@@ -680,7 +708,7 @@ int grib_get_double_elements(grib_handle* h, const char* name, int* i, long len,
 
   act= grib_find_accessor(h, name);
 
-  ret=grib_get_size(h,name,&size);
+  ret=_grib_get_size(h,act,&size);
 
   if (ret!=GRIB_SUCCESS) {
     grib_context_log(h->context,GRIB_LOG_ERROR,"grib_get_double_elements: cannot get size of %s\n",name);
@@ -1158,4 +1186,63 @@ void grib_print_values(grib_values* values,int count)
   }
 }
 
+int grib_values_check(grib_handle* h, grib_values* values, int count) {
+  int i=0;
+  long long_value;
+  double double_value;
+  unsigned char ubuff[1024]={0,};
+  char buff[1024]={0,};
+  size_t len=1024;
 
+  for (i=0; i<count; i++) {
+
+      if ( values[i].type == 0 ) {
+         values[i].error=GRIB_INVALID_TYPE;
+         return values[i].error;
+      }
+
+      switch(values[i].type) {
+        case GRIB_TYPE_LONG:
+          values[i].error = grib_get_long(h,values[i].name,&long_value);
+          if (values[i].error != GRIB_SUCCESS) return values[i].error;
+		  if (long_value != values[i].long_value) {
+			values[i].error=GRIB_VALUE_DIFFERENT;
+		    return values[i].error;
+		  }
+          break;
+
+        case GRIB_TYPE_DOUBLE:
+          values[i].error = grib_get_double(h,values[i].name,&double_value);
+          if (values[i].error != GRIB_SUCCESS) return values[i].error;
+		  if (double_value != values[i].double_value) {
+			values[i].error=GRIB_VALUE_DIFFERENT;
+		    return values[i].error;
+		  }
+          break;
+
+        case GRIB_TYPE_STRING:
+          values[i].error = grib_get_string(h,values[i].name,buff,&len);
+          if (values[i].error != GRIB_SUCCESS) return values[i].error;
+          if (strcmp(values[i].string_value,buff)) {
+            values[i].error=GRIB_VALUE_DIFFERENT;
+            return values[i].error;
+          }
+          break;
+
+        case GRIB_TYPE_BYTES:
+          values[i].error = grib_get_bytes(h,values[i].name,ubuff,&len);
+          if (values[i].error != GRIB_SUCCESS) return values[i].error;
+          if (memcmp(values[i].string_value,ubuff,len)) {
+            values[i].error=GRIB_VALUE_DIFFERENT;
+            return values[i].error;
+          }
+          break;
+
+        default:
+         values[i].error=GRIB_INVALID_TYPE;
+         return values[i].error;
+      }
+  }
+
+  return 0;
+}
