@@ -9,5 +9,7 @@
 
 . ./include.sh
 
-${tools_dir}grib_ls -7 ${data_dir}/bad.grib 2> /dev/null > /dev/null
+REDIRECT=/dev/null
+
+${tools_dir}grib_ls -7 ${data_dir}/bad.grib 2> $REDIRECT > $REDIRECT
 
