@@ -31,7 +31,7 @@ do
     
   #echo $gridType Ni=$Ni Nj=$Nj
 
-  N=$((Ni * Nj))
+N=`expr $Ni \* $Nj`
   cat > ${data_dir}/change_scanning_${gridType}.filter <<EOF
     set edition=$edition;
     set gridType="$gridType";
@@ -39,8 +39,8 @@ do
     set Nj=$Nj;
 	set latitudeFirstInDegrees=20.0;
 	set longitudeFirstInDegrees=20.0;
-	set latitudeLastInDegrees=$((20 - $Nj + 1));
-	set longitudeLastInDegrees=$((20 + $Ni - 1));
+	set latitudeLastInDegrees=`expr 20 - $Nj + 1`;
+	set longitudeLastInDegrees=`expr 20 + $Ni - 1`;
 	set DiInDegrees=1.0;
 	set DjInDegrees=1.0;
 	set iScansNegatively=0;
