@@ -9,6 +9,8 @@
 
 . ./include.sh
 
+REDIRECT=/dev/null
+
 if [ -f ${data_dir}/geavg.t12z.pgrbaf108 ]
 then
 
@@ -16,7 +18,7 @@ tmpdata=grib_api.grib
 
 rm -f $tmpdata || true
 
-${tools_dir}grib_filter ${data_dir}/filter_rules ${data_dir}/geavg.t12z.pgrbaf108 > /dev/null
+${tools_dir}grib_filter ${data_dir}/filter_rules ${data_dir}/geavg.t12z.pgrbaf108 > $REDIRECT
 
 rm -f $tmpdata
 
@@ -28,5 +30,5 @@ EOF
 
 [ -d ${data_dir}/split ] || mkdir -p ${data_dir}/split 
 
-${tools_dir}grib_filter ${data_dir}/f.rules ${data_dir}/tigge_pf_ecmwf.grib2 2> /dev/null > /dev/null
+${tools_dir}grib_filter ${data_dir}/f.rules ${data_dir}/tigge_pf_ecmwf.grib2 2> $REDIRECT > $REDIRECT
 
