@@ -9,9 +9,11 @@
 
 . ./include.sh
 
+REDIRECT=/dev/null
+
 set +e 
 
-${tools_dir}grib_get -p gribname ${data_dir}/regular_latlon_surface.grib1 2> /dev/null > /dev/null
+${tools_dir}grib_get -p gribname ${data_dir}/regular_latlon_surface.grib1 2> $REDIRECT > $REDIRECT
 
 if [ $? -eq 0 ] 
   then
