@@ -24,10 +24,12 @@ then
   GRIB_SAMPLES_PATH=$path/samples
   export GRIB_SAMPLES_PATH
   tools_dir=$path/tools/
+  tigge_dir=$path/tigge/
   data_dir=$path/data
   test_dir=$path/tests
 else
   tools_dir=""
+  tigge_dir=""
 fi
 
 if [ -z "${GRIB_API_INCLUDE}" ]
