@@ -49,7 +49,7 @@ grib_error* error_summary;
 compare_double_proc compare_double;
 double global_tolerance=0;
 int packingCompare=0;
-grib_string* blacklist=0;
+grib_string_list* blacklist=0;
 int compareAbsolute=1;
 
 static int compare_handles(grib_handle* h1,grib_handle* h2,grib_runtime_options* options);
@@ -58,7 +58,7 @@ int error=0;
 int count=0;
 int lastPrint=0;
 int force=0;
-double maxAbsoluteError = 1e-9;
+double maxAbsoluteError = 1e-19;
 int onlyListed=1;
 int headerMode=0;
 int morein1=0;
@@ -85,9 +85,9 @@ static double compare_double_relative(double *a,double *b,double *err) {
 }
 
 static int blacklisted(const char* name) {
-  grib_string* b=blacklist;
+  grib_string_list* b=blacklist;
   while (b) {
-    if (!strcmp(name,b->string))
+    if (!strcmp(name,b->value))
       return 1;
     b=b->next;
   }
@@ -96,7 +96,7 @@ static int blacklisted(const char* name) {
 
 static double relative_error(double a,double b,double err) {
   double relativeError;
-  double maxAbsoluteError = 1e-9;
+  double maxAbsoluteError = 1e-19;
 
   if(fabs(a) <= maxAbsoluteError || fabs(b) <= maxAbsoluteError)
     relativeError = fabs(a-b);
@@ -196,14 +196,14 @@ int grib_tool_init(grib_runtime_options* options) {
   }
     
   if (grib_options_on("b:")) {
-    grib_string *next=0;
+    grib_string_list *next=0;
     int i=0;
-    blacklist=grib_context_malloc_clear(context,sizeof(grib_string));
-    blacklist->string=grib_context_strdup(context,options->set_values[0].name);
+    blacklist=grib_context_malloc_clear(context,sizeof(grib_string_list));
+    blacklist->value=grib_context_strdup(context,options->set_values[0].name);
     next=blacklist;
     for (i=1;i<options->set_values_count;i++) {
-      next->next=grib_context_malloc_clear(context,sizeof(grib_string));
-      next->next->string=grib_context_strdup(context,options->set_values[i].name);
+      next->next=grib_context_malloc_clear(context,sizeof(grib_string_list));
+      next->next->value=grib_context_strdup(context,options->set_values[i].name);
       next=next->next;
     }
     context->blacklist=blacklist;
@@ -772,7 +772,13 @@ static int compare_values(grib_runtime_options* options,grib_handle* h1,grib_han
         save_error(c,name);
       }
       
-      if(err1 == GRIB_SUCCESS && err2 == GRIB_SUCCESS)
+      if(err1 == GRIB_SUCCESS && err2 == GRIB_SUCCESS && len1!=len2)
+	  {
+	  	printInfo(h1);
+		printf("Different size for \"%s\"  [%ld]  [%ld]\n",name,(long)len1,(long)len2);
+		save_error(c,name);
+	  }
+      if(err1 == GRIB_SUCCESS && err2 == GRIB_SUCCESS && len1==len2)
       {
         int i,imaxdiff;
         double diff;
@@ -925,10 +931,10 @@ static int compare_handles(grib_handle* h1,grib_handle* h2,grib_runtime_options*
 
   /* mask only if no -c option or headerMode (-H)*/
   if (blacklist && ( !listFromCommandLine || headerMode )) {
-    grib_string* nextb=blacklist;
+    grib_string_list* nextb=blacklist;
     while (nextb) {
-      grib_clear(h1,nextb->string);
-      grib_clear(h2,nextb->string);
+      grib_clear(h1,nextb->value);
+      grib_clear(h2,nextb->value);
       nextb=nextb->next;
     }
   }
