@@ -78,7 +78,7 @@ int grib_tool_new_handle_action(grib_runtime_options* options, grib_handle* h) {
   }
 
   err=grib_handle_apply_action(h,options->action);
-  if (err != GRIB_SUCCESS && options->fail) {
+  if (err != GRIB_SUCCESS && options->fail && err!=GRIB_NOT_FOUND) {
      printf("ERROR: %s\n",grib_get_error_message(err));
      exit(err);
   }
