@@ -94,7 +94,8 @@ grib_options_help grib_options_help_list[] ={
   {"S",0,"Strict. Only grib messages matching all the constraints are copied to"
    "\n\t\tthe output file\n"},
   {"V",0,"Version.\n"},
-  {"W:","width","\n\t\tMinimum width of each column in output. Default is 10.\n"}
+  {"W:","width","\n\t\tMinimum width of each column in output. Default is 10.\n"},
+  {"x",0,"Fast parsing option, only headers are loaded.\n"}
 
 };
 
@@ -170,6 +171,8 @@ int grib_process_runtime_options(grib_context* context,int argc,char** argv,grib
   if (grib_options_on("B:"))
     options->orderby=grib_options_get_option("B:");
 
+  if (grib_options_on("x")) options->headers_only=1;
+
   if (grib_options_on("F:"))
     options->format=grib_options_get_option("F:");
   else 
