@@ -95,6 +95,7 @@ grib_runtime_options options={
         0,         /* index2  */
         0,         /* context  */
         0,         /* stop  */
+        0,         /* headers_only  */
         {{0,},}    /* grib_values tolerance[MAX_KEYS] */
 
 	};
@@ -118,6 +119,13 @@ static int is_index_file(const char* filename) {
 	return ret;
 }
 
+static grib_handle* grib_handle_new_from_file_x(grib_context* c,FILE* f,int headers_only,int *err) {
+	if (headers_only) 
+		return grib_handle_headers_only_new_from_file(c,f,err);
+
+	return grib_handle_new_from_file(c,f,err);
+}
+
 int grib_tool(int argc, char **argv)
 {
 	int ret=0;
@@ -282,7 +290,7 @@ static int grib_tool_without_orderby(grib_runtime_options* options) {
 		grib_tool_new_file_action(options,infile);
 
 
-		while((h = grib_handle_new_from_file(c,infile->file,&err))
+		while((h = grib_handle_new_from_file_x(c,infile->file,options->headers_only,&err))
 				!= NULL || err != GRIB_SUCCESS ) {
 			infile->handle_count++;
 			options->handle_count++;
